window.Gleam.initSearch([{"doc":"redraw","title":"redraw","content":"# Redraw\n\nReact opinionated bindings for Gleam. Because a lot of frameworks and products\nare using React in a day-to-day way, Redraw fills the gap by providing nice,\nsimple API to work on a React codebase, Gleam-enhanced!\n\n&gt; [!TIP]\n&gt;\n&gt; Have you tried [Lustre](https://lustre.build)? Lustre requires almost no\n&gt; knowledge of JavaScript, no complicated runtimes to get like Node.js, few\n&gt; knowledge of HTML/CSS and other web technologies, less code interfaces to\n&gt; write than Redraw, and is supported by the entire Gleam community! Before\n&gt; launching into Redraw, you should take a look at Lustre, it provides a\n&gt; user-friendly, awesome experience right out-of-the-box for every gleamlins!\n&gt; Plus, Lustre is homomorphic, i.e. it can be used as well on client and on\n&gt; server with the same codebase! When using Redraw, you assume to have knowledge\n&gt; about frontend development.\n\n## Overview\n\nRedraw is a package to help you use React in a frontend-only Gleam project. By\nleveraging on the entire JS ecosystem, Redraw help you interop with existing\ncurrent React codebases, or allow you to build your custom codebase and\ncherry-picking the existing components you know and love! Redraw tries to keep\neverything at the lowest level possible, turning all the React niceties into\nGleam niceties. Wherever possible, Redraw tries to stick with Lustre API, to\nhelp you create a codebase mixing the two frameworks. For instance, you could\nbuild libraries targeting both Lustre and Redraw, and using the same design\nsystem for all your products!\n\n## Prerequisites\n\nRedraw assumes that you&#39;re a fluent frontend developer and already understand\nhow React works. If you don&#39;t, it&#39;s best to first learn React and the frontend\necosystem, and come back here later. Meanwhile, you could also take a look at\n[Lustre](https://lustre.build) to solve your problems.\n\nRedraw assumes you have [`node.js`](https://nodejs.org/en) as well as a decent\npackage manager, i.e. `npm`, `yarn` or `pnpm`. Redraw also assumes you&#39;re using\n[`Vite`](https://vitejs.dev/) as a tooling, to build your application.\n\n## Getting started\n\nCreate the project, and add everything needed to make it work. Choose your\nprefered bundler to start. Create a Vite application, and choose to use\nJavaScript and React. Vite should bundle everything for you directly.\n\n```sh\nnpm create vite@latest\n```\n\n```sh\nyarn create vite\n```\n\n```sh\npnpm create vite\n```\n\n```sh\nbun create vite\n```\n\nFrom the follow-on, `yarn` will be used to illustrate the commands, it&#39;s up to\nyou to see how to use your desired package manager. Then, it&#39;s time to setup the\nproject correctly.\n\n```sh\ncd [project-name]\nyarn install\n\n# Install the Vite Gleam plugin.\nyarn add -D vite-gleam\n\n# If you want to build the project on Vercel or Netlify.\nyarn add -D @chouqueth/gleam\n\n# Remove the files needed for `gleam new` to work.\nrm README.md\nmv .gitignore .gitignore.old\n\n# Setup the project.\ngleam new .\ngleam add redraw redraw_dom\n```\n\nNow that everyting is setup, you have to add the `vite-gleam` plugin in\n`vite.config.js`. An example of a `vite.config.js` should look like this.\n\n```javascript\nimport { defineConfig } from &quot;vite&quot;\nimport react from &quot;@vitejs/plugin-react&quot;\nimport gleam from &quot;vite-gleam&quot;\n\n// https://vitejs.dev/config/\nexport default defineConfig({\n  plugins: [react(), gleam()],\n})\n```\n\nYou&#39;re good to go!\n\n## Writing Redraw components\n\nWriting Redraw components is the same as writing React component, with one small\ndifference: wrap the component in `use &lt;- redraw.component()`!\n\n```gleam\nimport redraw\nimport redraw/attribute\nimport redraw/html\n\npub fn gleam_is_awesome() {\n  use &lt;- redraw.component__(&quot;GleamIsAwesome&quot;)\n  html.div([attribute.class(&quot;oh-yeah&quot;)], [\n    html.text(&quot;Yeah, for sure&quot;)\n  ])\n}\n```\n\nWhile this could feels strange at first, you&#39;ll get used to it quickly. To call\nthe component, it&#39;s needed to call the function first, _before definining a new\ncomponent_.\n\n```gleam\nimport redraw\nimport redraw/attribute\nimport redraw/html\nimport redraw_dom/client\n\npub fn main() {\n  let root = root()\n  client.create_root(&quot;root&quot;)\n  |&gt; client.render(redraw.strict_mode([root()]))\n}\n\nfn root() {\n  // Call `gleam_is_awesome` here, before component creation, otherwise a new\n  // component will be created at each refresh.\n  let gleam_is_awesome = gleam_is_awesome()\n  use &lt;- redraw.component__(&quot;Root&quot;)\n  html.div([], [\n    gleam_is_awesome()\n  ])\n}\n\nfn gleam_is_awesome() {\n  use &lt;- redraw.component__(&quot;GleamIsAwesome&quot;)\n  html.div([attribute.class(&quot;oh-yeah&quot;)], [\n    html.text(&quot;Yeah, for sure&quot;)\n  ])\n}\n```\n\nAnd you know everything to create Redraw components!\n\n## What is the kind of components?\n\nComponents can have different kinds, accepting props, children, ref, or other\nthings. To provide a simpler, usable API in Gleam, props components in Gleam can\nbe List, Tuple or CustomTypes. It means you can totally define your component\nlike this:\n\n```gleam\npub type CounterProps {\n  CounterProps(\n    count: Int,\n    set_count: fn(fn(Int) -&gt; Int) -&gt; Nil,\n  )\n}\n\npub fn counter() {\n  use props: CounterProps &lt;- react.component_(&quot;Counter&quot;)\n  html.button(\n    [h.on_click(fn(_) { props.set_count(fn(count) { count + 1 }) })],\n    [html.text(&quot;count is &quot; &lt;&gt; int.to_string(props.count))],\n  )\n}\n```\n\nbut also like this:\n\n```gleam\npub type CounterProps = #(Int, fn(fn(Int) -&gt; Int) -&gt; Nil)\n\npub fn counter() {\n  use #(count, set_count): CounterProps &lt;- react.component_(&quot;Counter&quot;)\n  html.button(\n    [h.on_click(fn(_) { set_count(fn(count) { count + 1 }) })],\n    [html.text(&quot;count is &quot; &lt;&gt; int.to_string(count))],\n  )\n}\n```\n\nDon&#39;t worry about the translation of data from and to React, Redraw handles the\nhard task for you!\n\n### `component`-family functions\n\nTo define components, you should use `component`, `component_` or `component__`.\nThe difference between the three is the signature of the resulting component.\n`component` accepts props and children, `component_` accepts only props, and\n`component__` do not accept anything. See it as a way to create an empty\ncomponent, used with contexts or internal state for instance.\n\n### `forward_ref`-family functions\n\nDefining components sometimes involves to forward a ref to internal component.\nReact uses the mechanism of `forwardRef` to push a ref, from the parent to a\nnested child. Redraw fully implements forwarded ref components! Use\n`forward_ref` or `forward_ref_` to create a component with props, ref and\nchildren, or only with props and children!\n\n## Some reminders on hooks\n\nNever use hooks outside of custom hooks (functions named `use_[something]`) or\nin components! It means you should never use something like `use_effect` or\n`use_state` outside of the body of `component`-related functions. If you break\nthat rule, while it could seem to work, it&#39;s actually breaking the runtime, and\nit can explode at any time. So keep that rule anytime: no hooks outside of\ncustom hooks or component body.\n\n## Type-checking of hooks\n\nYou could see that hooks often use dependencies array, to determine if they have\nto rerun or not. This is totally supported by Redraw, and leverages on Gleam\nabilities! Always pass a tuple of dependencies to hooks. No type-checking are\ndone at this stage, and probably none will be implemented later, exactly like\nit&#39;s done with React currently. Be careful to provide the correct dependencies.\n\n```gleam\nimport gleam/io\nimport redraw\nimport redraw/attribute\nimport redraw/html\n\nfn gleam_is_awesome() {\n  use &lt;- redraw.component__(&quot;GleamIsAwesome&quot;)\n  redraw.use_effect(fn() {\n    io.println(&quot;Hello from component!&quot;)\n  }, #()) // Passing an empty tuple here is like passing [] in JavaScript.\n  html.div([attribute.class(&quot;oh-yeah&quot;)], [\n    html.text(&quot;Yeah, for sure&quot;)\n  ])\n}\n```\n\n## Using external components\n\nReact is greatly used everywhere. It means a lot of components are already\nusable out-of-the-box. Happily, Redraw provides a way to interop directly with\nthem! Use `to_component` and `to_component_` to integrate a foreign function\ndirectly. Define the correct props, and your work is done! Don&#39;t worry about\nsnake_case and camelCase of props name, Redraw take care of the translation for\nyou. Everytime you put an `Option(a)`, Redraw will also translate it to\n`a | null`, because React use the convention to pass `null` everywhere instead\nof optionals.\n\n```gleam\nimport gleam/option.{type Option}\nimport redraw\nimport redraw/html\n\n// This type will be converted to correct JS props.\npub type ExternalComponentProps {\n  ExternalComponentProps(\n    first_field: Bool,             // firstField: bool\n    second_field: Bool,            // secondField: bool\n    optional_field: Option(String) // optionalField: string | null\n  )\n}\n\n@external(javascript, &quot;external_module&quot;, &quot;ExternalComponent&quot;)\nfn external_component_ffi(props: a) -&gt; redraw.Component\n\nfn external_component() -&gt; fn(ExternalComponentProps) -&gt; redraw.Component {\n  redraw.to_component_(&quot;ExternalComponent&quot;, external_component_ffi)\n}\n\npub fn my_other_component() {\n  let external_component = external_component()\n  use &lt;- redraw.component__(&quot;OtherComponent&quot;)\n  html.div([], [\n    external_component(\n      ExternalComponentProps(\n        first_field: True,\n        second_field: False,\n        optional_field: option.None,\n      )\n    )\n  ])\n}\n```\n\n## Miscellaneous\n\nSome questions, answers, and various informations.\n\n### What is the state of support for React Native, or any other React flavor?\n\nReact is an isolated packages, and renderers can be various. Redraw has\nsuccessfully be used with Raycast. You can also easily add a `redraw_native`\npackage, and provide an interface for native components. Everything can be done\nquickly and easily, because the entire package is written with as few JS as\npossible. Everything should work almost out-of-the box, because React is already\nworking there. You should take inspiration at how is working `redraw/html`, and\nit could work in the exact same way. It&#39;s only a matter of providing the correct\nComponent to `jsx`.\n\n### Contributing\n\nDo you love the package? You can contribute! Feel free to open a PR, or open an\nissue!\n\n### Why wrapping every components in `use props &lt;- component(name)`?\n\nIf you&#39;re used to React, you know a component is no more than a function,\nreturning a `ReactNode`. Something like this:\n\n```javascript\nfunction GleamIsAwesome(props) {\n  return &lt;div className=&quot;oh-yeah&quot;&gt;Yeah, for sure&lt;/div&gt;\n}\n```\n\nActually, because of JSX, React is a bit lying to all of us, and compiles it to:\n\n```javascript\nimport { jsx } from &quot;react/runtime-jsx&quot;\n\nfunction GleamIsAwesome(props) {\n  return jsx(&quot;div&quot;, { className: &quot;oh-yeah&quot;, children: &quot;Yeah, for sure&quot; })\n}\n```\n\nReact injects a call to `jsx` before every JSX render. This allows for the\nruntime to determine if the function should be called once again with the new\nprovided props. It&#39;s also true for functions.\n\n```javascript\n// That code\nfunction ILoveBeam(props) {\n  return &lt;div&gt;BEAM 💜&lt;/div&gt;\n}\n\nfunction GleamIsAwesome(props) {\n  return (\n    &lt;div className=&quot;oh-yeah&quot;&gt;\n      &lt;ILoveBeam /&gt;\n      Yeah, for sure\n    &lt;/div&gt;\n  )\n}\n\n// Turns into\nimport { jsx, jsxs } from &quot;react/runtime-jsx&quot;\n\nfunction ILoveBeam(props) {\n  return jsx(&quot;div&quot;, { children: &quot;BEAM 💜&quot; })\n}\n\nfunction GleamIsAwesome(props) {\n  return jsxs(&quot;div&quot;, {\n    className: &quot;oh-yeah&quot;,\n    children: [jsx(ILoveBeam, {}), &quot;Yeah, for sure&quot;],\n  })\n}\n```\n\nHere, we got a problem: we cannot inject the `jsx` call before `ILoveBeam` in\nGleam. What we could do is write a function that generate the `jsx` call with an\nother function with `use`, but anonymous functions cannot be used with React:\nReact is doing referential equality for Functional Components. Every component\nshould be defined once and for all.\n\nTo inject the `jsx` call properly, it would requires an additional\ncompilation-step. Because we cannot do this, we pass by a generator function.\nThat&#39;s what `use props &lt;- component(name)` is doing. To get the correct result,\nwe go to a _Component creator_, a function that create a component once and for\nall from a `render` function. Everytime we create a component, we use a render\nfunction and turns it into a proper component to be used with React.\n","url":"index.html"},{"doc":"redraw","title":"Component","content":"pub type Component\n Default Node in redraw. Use `component`-family functions to create components.\n Forwarded ref can be constructed using `forward_ref`-family functions, while\n external components can be used with `to_component`-family functions.\n\nSynonyms:\nredraw.Component\nredraw Component","url":"redraw.html#Component"},{"doc":"redraw","title":"Context","content":"pub type Context(a)\n Pass data without props drilling.\n [Documentation](https://redraw.dev/learn/passing-data-deeply-with-context)\n\nSynonyms:\nredraw.Context\nredraw Context","url":"redraw.html#Context"},{"doc":"redraw","title":"Ref","content":"pub type Ref(a)\n A Ref is a mutable data stored in React, persisted across renders.\n They allow to keep track of a DOM node, a component data, or to store a\n mutable variable in the component, outside of every component lifecycle.\n\nSynonyms:\nredraw.Ref\nredraw Ref","url":"redraw.html#Ref"},{"doc":"redraw","title":"Suspense","content":"pub type Suspense {\n  Suspense(fallback: Component)\n}\n\nSuspense(fallback: Component)\n\n\nSynonyms:\nredraw.Suspense\nredraw Suspense","url":"redraw.html#Suspense"},{"doc":"redraw","title":"act","content":"pub fn act(act_fn: fn() -&gt; Promise(Nil)) -&gt; Promise(Nil)\n Test helper to apply pending React updates before making assertions.\n [Documentation](https://redraw.dev/reference/redraw/act)\nSynonyms:\nredraw.act\nredraw act","url":"redraw.html#act"},{"doc":"redraw","title":"component","content":"pub fn component(\n  name name: String,\n  render render: fn(a, List(Component)) -&gt; Component,\n) -&gt; fn(a, List(Component)) -&gt; Component\n Create a Redraw component, with a `name`, and a `render` function. `render`\n will accept props, and a list of children.\nSynonyms:\nredraw.component\nredraw component","url":"redraw.html#component"},{"doc":"redraw","title":"component_","content":"pub fn component_(\n  name name: String,\n  render render: fn(a) -&gt; Component,\n) -&gt; fn(a) -&gt; Component\n Create a Redraw component, with a `name`, and a `render` function. This\n component does not accept children.\nSynonyms:\nredraw.component_\nredraw component_","url":"redraw.html#component_"},{"doc":"redraw","title":"component__","content":"pub fn component__(\n  name name: String,\n  render render: fn() -&gt; Component,\n) -&gt; fn() -&gt; Component\n Create a Redraw component, with a `name` and a `render` function. This\n component does not accept children nor props.\nSynonyms:\nredraw.component__\nredraw component__","url":"redraw.html#component__"},{"doc":"redraw","title":"create_context","content":"pub fn create_context(\n  default_value default_value: Option(a),\n) -&gt; Context(a)\n Let you create a [context](https://redraw.dev/learn/passing-data-deeply-with-context) that components can provide or read.\n [Documentation](https://redraw.dev/reference/redraw/createContext)\nSynonyms:\nredraw.create_context\nredraw create_context","url":"redraw.html#create_context"},{"doc":"redraw","title":"forward_ref","content":"pub fn forward_ref(\n  name name: String,\n  render render: fn(a, Ref(b), List(Component)) -&gt; Component,\n) -&gt; fn(a, Ref(b), List(Component)) -&gt; Component\n Create a Redraw component with children with forwarded ref. Take a look at\n [redraw.dev documentation to get more info.](https://fr.redraw.dev/reference/redraw/forwardRef)\nSynonyms:\nredraw.forward_ref\nredraw forward_ref","url":"redraw.html#forward_ref"},{"doc":"redraw","title":"forward_ref_","content":"pub fn forward_ref_(\n  name name: String,\n  render render: fn(a, Ref(b)) -&gt; Component,\n) -&gt; fn(a, Ref(b)) -&gt; Component\n Create a Redraw component without children with forwarded ref. Take a look at\n [redraw.dev documentation to get more info.](https://redraw.dev/reference/redraw/forwardRef)\nSynonyms:\nredraw.forward_ref_\nredraw forward_ref_","url":"redraw.html#forward_ref_"},{"doc":"redraw","title":"fragment","content":"pub fn fragment(children: List(Component)) -&gt; Component\n Fragment allow to group children, without creating a node in the DOM.\n [Documentation](https://redraw.dev/reference/redraw/Fragment)\nSynonyms:\nredraw.fragment\nredraw fragment","url":"redraw.html#fragment"},{"doc":"redraw","title":"get_current","content":"pub fn get_current(from ref: Ref(a)) -&gt; a\n Get the current value of a ref.\nSynonyms:\nredraw.get_current\nredraw get_current","url":"redraw.html#get_current"},{"doc":"redraw","title":"keyed","content":"pub fn keyed(\n  element: fn(List(Component)) -&gt; Component,\n  content: List(#(String, Component)),\n) -&gt; Component\n Redraw does not support passing key element to components in an easy way like\n React does. To simplify this, it uses the same API than [Lustre](lustre.build)\n to put keys on children.\n \n fn my_component(props, children) {\n   redraw.keyed(my_other_component(props, _), {\n     use item &lt;- list.map(children)\n     #(&quot;my-key&quot;, item)\n   })\n }\n \nSynonyms:\nredraw.keyed\nredraw keyed","url":"redraw.html#keyed"},{"doc":"redraw","title":"memo","content":"pub fn memo(\n  component: fn(a, List(Component)) -&gt; Component,\n) -&gt; fn(a, List(Component)) -&gt; Component\n Memoizes a Redraw component with children.\nSynonyms:\nredraw.memo\nredraw memo","url":"redraw.html#memo"},{"doc":"redraw","title":"memo_","content":"pub fn memo_(component: fn(a) -&gt; Component) -&gt; fn(a) -&gt; Component\n Memoizes a Redraw component without children.\nSynonyms:\nredraw.memo_\nredraw memo_","url":"redraw.html#memo_"},{"doc":"redraw","title":"profiler","content":"pub fn profiler(children: List(Component)) -&gt; Component\n Profile allows to measure code performance for a component tree.\n [Documentation](https://redraw.dev/reference/redraw/Profiler)\nSynonyms:\nredraw.profiler\nredraw profiler","url":"redraw.html#profiler"},{"doc":"redraw","title":"provider","content":"pub fn provider(\n  context context: Context(a),\n  value value: a,\n  children children: List(Component),\n) -&gt; Component\n Wrap your components into a context provider to specify the value of this context for all components inside.\n [Documentation](https://redraw.dev/reference/redraw/createContext#provider)\nSynonyms:\nredraw.provider\nredraw provider","url":"redraw.html#provider"},{"doc":"redraw","title":"set_current","content":"pub fn set_current(of ref: Ref(a), with value: a) -&gt; Nil\n Set the current value of a ref, overriding its existing content.\nSynonyms:\nredraw.set_current\nredraw set_current","url":"redraw.html#set_current"},{"doc":"redraw","title":"start_transition","content":"pub fn start_transition(scope scope: fn() -&gt; Nil) -&gt; Nil\n Let you update the state without blocking the UI.\n [Documentation](https://redraw.dev/reference/redraw/startTransition)\nSynonyms:\nredraw.start_transition\nredraw start_transition","url":"redraw.html#start_transition"},{"doc":"redraw","title":"strict_mode","content":"pub fn strict_mode(children: List(Component)) -&gt; Component\n Strict Mode should be enabled during development.\n [Documentation](https://redraw.dev/reference/redraw/StrictMode)\nSynonyms:\nredraw.strict_mode\nredraw strict_mode","url":"redraw.html#strict_mode"},{"doc":"redraw","title":"suspense","content":"pub fn suspense(\n  props: Suspense,\n  children: List(Component),\n) -&gt; Component\n Suspense allow to display a fallback content while waiting for children to\n finish loading.\n [Documentation](https://fr.redraw.dev/reference/redraw/Suspense)\nSynonyms:\nredraw.suspense\nredraw suspense","url":"redraw.html#suspense"},{"doc":"redraw","title":"to_component","content":"pub fn to_component(\n  name name: String,\n  component render: fn(a) -&gt; Component,\n) -&gt; fn(b, List(Component)) -&gt; Component\n Convert a React component to a React-redraw component with children. Give it a\n name, and send directly the FFI. Don&#39;t worry about the snake_case over\n camelCase, redraw take care of it for you.\n\n \n import redraw\n\n @external(javascript, &quot;my_library&quot;, &quot;MyComponent&quot;)\n fn do_my_component(props: props) -&gt; redraw.Component\n\n pub type MyComponentProps {\n   MyComponentProps(\n     first_prop: Bool,\n     second_prop: String,\n   )\n }\n\n pub fn my_component() -&gt; fn(MyComponentProps) -&gt; redraw.Component {\n   redraw.to_component(&quot;MyComponent&quot;, do_my_component)\n }\n \nSynonyms:\nredraw.to_component\nredraw to_component","url":"redraw.html#to_component"},{"doc":"redraw","title":"to_component_","content":"pub fn to_component_(\n  name name: String,\n  component render: fn(a) -&gt; Component,\n) -&gt; fn(b) -&gt; Component\n Convert a React Component to a redraw Component without children. Give it a\n name, and send directly the FFI. Don&#39;t worry about the snake_case over\n camelCase, redraw take care of it for you.\n\n \n import redraw\n\n @external(javascript, &quot;my_library&quot;, &quot;MyComponent&quot;)\n fn do_my_component(props: props) -&gt; redraw.Component\n\n pub type MyComponentProps {\n   MyComponentProps(\n     first_prop: Bool,\n     second_prop: String,\n   )\n }\n\n pub fn my_component() -&gt; fn(MyComponentProps) -&gt; redraw.Component {\n   redraw.to_component_(&quot;MyComponent&quot;, do_my_component)\n }\n \nSynonyms:\nredraw.to_component_\nredraw to_component_","url":"redraw.html#to_component_"},{"doc":"redraw","title":"use_callback","content":"pub fn use_callback(fun: a, dependencies: b) -&gt; c\n Let you cache a function definition between re-renders.\n `dependencies` should be a tuple.\n [Documentation](https://redraw.dev/reference/redraw/useCallback)\nSynonyms:\nredraw.use_callback\nredraw use_callback","url":"redraw.html#use_callback"},{"doc":"redraw","title":"use_context","content":"pub fn use_context(context: Context(a)) -&gt; a\n Let you read and subscribe to [context](https://redraw.dev/learn/passing-data-deeply-with-context) from your component.\n [Documentation](https://redraw.dev/reference/redraw/useContext)\nSynonyms:\nredraw.use_context\nredraw use_context","url":"redraw.html#use_context"},{"doc":"redraw","title":"use_debug_value","content":"pub fn use_debug_value(value: a) -&gt; Nil\n Let you add a label to a custom Hook in React DevTools.\n [Documentation](https://redraw.dev/reference/redraw/useDebugValue)\nSynonyms:\nredraw.use_debug_value\nredraw use_debug_value","url":"redraw.html#use_debug_value"},{"doc":"redraw","title":"use_debug_value_","content":"pub fn use_debug_value_(\n  value: a,\n  formatter: fn(a) -&gt; String,\n) -&gt; Nil\n Let you add a label to a custom Hook in React DevTools, but allow to format\n it before.\n [Documentation](https://redraw.dev/reference/redraw/useDebugValue)\nSynonyms:\nredraw.use_debug_value_\nredraw use_debug_value_","url":"redraw.html#use_debug_value_"},{"doc":"redraw","title":"use_deferred_value","content":"pub fn use_deferred_value(value: a) -&gt; a\n Let you defer updating a part of the UI.\n [Documentation](https://redraw.dev/reference/redraw/useDeferredValue)\nSynonyms:\nredraw.use_deferred_value\nredraw use_deferred_value","url":"redraw.html#use_deferred_value"},{"doc":"redraw","title":"use_effect","content":"pub fn use_effect(value: fn() -&gt; Nil, dependencies: a) -&gt; Nil\n Let you synchronize a component with an external system.\n [Documentation](https://redraw.dev/reference/redraw/useEffect)\nSynonyms:\nredraw.use_effect\nredraw use_effect","url":"redraw.html#use_effect"},{"doc":"redraw","title":"use_id","content":"pub fn use_id() -&gt; String\n Generate unique IDs that can be passed to accessibility attributes.\n [Documentation](https://redraw.dev/reference/redraw/useId)\nSynonyms:\nredraw.use_id\nredraw use_id","url":"redraw.html#use_id"},{"doc":"redraw","title":"use_imperative_handle","content":"pub fn use_imperative_handle(\n  ref: Ref(Option(a)),\n  handler: fn() -&gt; a,\n  dependencies: b,\n) -&gt; Nil\n Let you customize the handle exposed as a [ref](https://redraw.dev/learn/manipulating-the-dom-with-refs).\n Use `use_imperative_handle` when you want to customize the data stored in\n a ref. It&#39;s mostly used in conjuction with `forward_ref`.\n [Documentation](https://redraw.dev/reference/redraw/useImperativeHandle)\nSynonyms:\nredraw.use_imperative_handle\nredraw use_imperative_handle","url":"redraw.html#use_imperative_handle"},{"doc":"redraw","title":"use_imperative_handle_","content":"pub fn use_imperative_handle_(\n  ref: Ref(a),\n  handler: fn() -&gt; a,\n  dependencies: b,\n) -&gt; Nil\n Let you customize the handle exposed as a [ref](https://redraw.dev/learn/manipulating-the-dom-with-refs).\n Use `use_imperative_handle` by default, unless you really know what you&#39;re\n doing.\n [Documentation](https://redraw.dev/reference/redraw/useImperativeHandle)\nSynonyms:\nredraw.use_imperative_handle_\nredraw use_imperative_handle_","url":"redraw.html#use_imperative_handle_"},{"doc":"redraw","title":"use_layout_effect","content":"pub fn use_layout_effect(\n  value: fn() -&gt; Nil,\n  dependencies: a,\n) -&gt; Nil\n Version of useEffect that fires before the browser repaints the screen.\n [Documentation](https://redraw.dev/reference/redraw/useLayoutEffect)\nSynonyms:\nredraw.use_layout_effect\nredraw use_layout_effect","url":"redraw.html#use_layout_effect"},{"doc":"redraw","title":"use_lazy_state","content":"pub fn use_lazy_state(\n  initial_value: fn() -&gt; a,\n) -&gt; #(a, fn(a) -&gt; Nil)\n Let you add a [state variable](https://redraw.dev/learn/state-a-components-memory) to your component.\n Allow to create the initial value in a lazy way.\n [Documentation](https://redraw.dev/reference/redraw/useState)\nSynonyms:\nredraw.use_lazy_state\nredraw use_lazy_state","url":"redraw.html#use_lazy_state"},{"doc":"redraw","title":"use_lazy_state_","content":"pub fn use_lazy_state_(\n  initial_value: fn() -&gt; a,\n) -&gt; #(a, fn(fn(a) -&gt; a) -&gt; Nil)\n Let you add a [state variable](https://redraw.dev/learn/state-a-components-memory) to your component.\n Allow to create the initial value in a lazy way.\n Give an `updater` function instead of a state setter.\n [Documentation](https://redraw.dev/reference/redraw/useState)\nSynonyms:\nredraw.use_lazy_state_\nredraw use_lazy_state_","url":"redraw.html#use_lazy_state_"},{"doc":"redraw","title":"use_memo","content":"pub fn use_memo(calculate_value: fn() -&gt; a, dependencies: b) -&gt; a\n Let you cache the result of a calculation between re-renders.\n [Documentation](https://redraw.dev/reference/redraw/useMemo)\nSynonyms:\nredraw.use_memo\nredraw use_memo","url":"redraw.html#use_memo"},{"doc":"redraw","title":"use_reducer","content":"pub fn use_reducer(\n  reducer: fn(a, b) -&gt; a,\n  initial_state: a,\n) -&gt; #(a, fn(b) -&gt; Nil)\n Let you add a [reducer](https://redraw.dev/learn/extracting-state-logic-into-a-reducer) to your component.\n [Documentation](https://redraw.dev/reference/redraw/useReducer)\nSynonyms:\nredraw.use_reducer\nredraw use_reducer","url":"redraw.html#use_reducer"},{"doc":"redraw","title":"use_reducer_","content":"pub fn use_reducer_(\n  reducer: fn(a, b) -&gt; a,\n  initializer: c,\n  init: fn(c) -&gt; a,\n) -&gt; #(a, fn(b) -&gt; Nil)\n Let you add a [reducer](https://redraw.dev/learn/extracting-state-logic-into-a-reducer) to your component.\n Allow to initialize the store in a custom way.\n [Documentation](https://redraw.dev/reference/redraw/useReducer)\nSynonyms:\nredraw.use_reducer_\nredraw use_reducer_","url":"redraw.html#use_reducer_"},{"doc":"redraw","title":"use_ref","content":"pub fn use_ref() -&gt; Ref(Option(a))\n Let you reference a value that’s not needed for rendering.\n Most used ref you&#39;ll want to create. They&#39;re automatically created to `None`,\n and can be passed to `attribute.ref` or `use_imperative_handle`.\n You probably don&#39;t want the ref value to be anything than `Option(a)`, unless\n you have really strong reasons.\n [Documentation](https://redraw.dev/reference/redraw/useRef)\nSynonyms:\nredraw.use_ref\nredraw use_ref","url":"redraw.html#use_ref"},{"doc":"redraw","title":"use_ref_","content":"pub fn use_ref_(initial_value: a) -&gt; Ref(a)\n Let you reference a value that’s not needed for rendering.\n Use `use_ref` if you&#39;re trying to acquire a reference to a child or to a\n component. Use `use_ref_` when you want to keep track of a data, like if\n you&#39;re doing some side-effects, in conjuction with `get_current` and\n `set_current`.\n [Documentation](https://redraw.dev/reference/redraw/useRef)\nSynonyms:\nredraw.use_ref_\nredraw use_ref_","url":"redraw.html#use_ref_"},{"doc":"redraw","title":"use_state","content":"pub fn use_state(initial_value: a) -&gt; #(a, fn(a) -&gt; Nil)\n Let you add a [state variable](https://redraw.dev/learn/state-a-components-memory) to your component.\n [Documentation](https://redraw.dev/reference/redraw/useState)\nSynonyms:\nredraw.use_state\nredraw use_state","url":"redraw.html#use_state"},{"doc":"redraw","title":"use_state_","content":"pub fn use_state_(\n  initial_value: a,\n) -&gt; #(a, fn(fn(a) -&gt; a) -&gt; Nil)\n Let you add a [state variable](https://redraw.dev/learn/state-a-components-memory) to your component.\n Give an `updater` function instead of a state setter.\n [Documentation](https://redraw.dev/reference/redraw/useState)\nSynonyms:\nredraw.use_state_\nredraw use_state_","url":"redraw.html#use_state_"},{"doc":"redraw","title":"use_transition","content":"pub fn use_transition() -&gt; #(Bool, fn() -&gt; Nil)\n Let you update the state without blocking the UI.\n [Documentation](https://redraw.dev/reference/redraw/useTransition)\nSynonyms:\nredraw.use_transition\nredraw use_transition","url":"redraw.html#use_transition"},{"doc":"redraw","title":"redraw","content":"","url":"redraw.html"},{"doc":"redraw/attribute","title":"Attribute","content":"pub type Attribute =\n  attribute.Attribute\n\n\nSynonyms:\nredraw/attribute.Attribute\nredraw/attribute Attribute","url":"redraw/attribute.html#Attribute"},{"doc":"redraw/attribute","title":"Dir","content":"pub type Dir {\n  Ltr\n  Rtl\n}\n\nLtr\n\n\nRtl\n\n\nSynonyms:\nredraw/attribute.Dir\nredraw/attribute Dir","url":"redraw/attribute.html#Dir"},{"doc":"redraw/attribute","title":"InnerHTML","content":"pub type InnerHTML\n\n\nSynonyms:\nredraw/attribute.InnerHTML\nredraw/attribute InnerHTML","url":"redraw/attribute.html#InnerHTML"},{"doc":"redraw/attribute","title":"Translate","content":"pub type Translate {\n  Yes\n  No\n}\n\nYes\n\n\nNo\n\n\nSynonyms:\nredraw/attribute.Translate\nredraw/attribute Translate","url":"redraw/attribute.html#Translate"},{"doc":"redraw/attribute","title":"attribute","content":"pub const attribute: fn(String, a) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.attribute\nredraw/attribute attribute","url":"redraw/attribute.html#attribute"},{"doc":"redraw/attribute","title":"accept","content":"pub fn accept(types: List(String)) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.accept\nredraw/attribute accept","url":"redraw/attribute.html#accept"},{"doc":"redraw/attribute","title":"accept_charset","content":"pub fn accept_charset(types: List(String)) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.accept_charset\nredraw/attribute accept_charset","url":"redraw/attribute.html#accept_charset"},{"doc":"redraw/attribute","title":"access_key","content":"pub fn access_key(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.access_key\nredraw/attribute access_key","url":"redraw/attribute.html#access_key"},{"doc":"redraw/attribute","title":"action","content":"pub fn action(url: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.action\nredraw/attribute action","url":"redraw/attribute.html#action"},{"doc":"redraw/attribute","title":"alt","content":"pub fn alt(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.alt\nredraw/attribute alt","url":"redraw/attribute.html#alt"},{"doc":"redraw/attribute","title":"aria","content":"pub fn aria(key: String, value: String) -&gt; Attribute\n Set aria attribute on the node. Should be used like `aria(&quot;valuenow&quot;, &quot;75&quot;)`.\nSynonyms:\nredraw/attribute.aria\nredraw/attribute aria","url":"redraw/attribute.html#aria"},{"doc":"redraw/attribute","title":"auto_capitalize","content":"pub fn auto_capitalize(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.auto_capitalize\nredraw/attribute auto_capitalize","url":"redraw/attribute.html#auto_capitalize"},{"doc":"redraw/attribute","title":"autocomplete","content":"pub fn autocomplete(name: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.autocomplete\nredraw/attribute autocomplete","url":"redraw/attribute.html#autocomplete"},{"doc":"redraw/attribute","title":"autofocus","content":"pub fn autofocus(should_autofocus: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.autofocus\nredraw/attribute autofocus","url":"redraw/attribute.html#autofocus"},{"doc":"redraw/attribute","title":"autoplay","content":"pub fn autoplay(should_autoplay: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.autoplay\nredraw/attribute autoplay","url":"redraw/attribute.html#autoplay"},{"doc":"redraw/attribute","title":"checked","content":"pub fn checked(is_checked: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.checked\nredraw/attribute checked","url":"redraw/attribute.html#checked"},{"doc":"redraw/attribute","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.class\nredraw/attribute class","url":"redraw/attribute.html#class"},{"doc":"redraw/attribute","title":"class_name","content":"pub fn class_name(value: String) -&gt; Attribute\n Alias of `class`.\nSynonyms:\nredraw/attribute.class_name\nredraw/attribute class_name","url":"redraw/attribute.html#class_name"},{"doc":"redraw/attribute","title":"cols","content":"pub fn cols(val: Int) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.cols\nredraw/attribute cols","url":"redraw/attribute.html#cols"},{"doc":"redraw/attribute","title":"content_editable","content":"pub fn content_editable(value: Bool) -&gt; Attribute\n If true, the browser lets the user edit the rendered element directly. This is used to implement rich text input libraries like Lexical. React warns if you try to pass React children to an element with contentEditable={true} because React will not be able to update its content after user edits.\nSynonyms:\nredraw/attribute.content_editable\nredraw/attribute content_editable","url":"redraw/attribute.html#content_editable"},{"doc":"redraw/attribute","title":"controls","content":"pub fn controls(visible: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.controls\nredraw/attribute controls","url":"redraw/attribute.html#controls"},{"doc":"redraw/attribute","title":"dangerously_set_inner_html","content":"pub fn dangerously_set_inner_html(\n  inner_html: InnerHTML,\n) -&gt; Attribute\n Overrides the innerHTML property of the DOM node and displays the passed HTML inside. This should be used with extreme caution! If the HTML inside isn’t trusted (for example, if it’s based on user data), you risk introducing an XSS vulnerability.\nSynonyms:\nredraw/attribute.dangerously_set_inner_html\nredraw/attribute dangerously_set_inner_html","url":"redraw/attribute.html#dangerously_set_inner_html"},{"doc":"redraw/attribute","title":"data","content":"pub fn data(key: String, value: String) -&gt; Attribute\n Data attributes let you attach some string data to the element, for example data-fruit=&quot;banana&quot;. In React, they are not commonly used because you would usually read data from props or state instead.\nSynonyms:\nredraw/attribute.data\nredraw/attribute data","url":"redraw/attribute.html#data"},{"doc":"redraw/attribute","title":"dir","content":"pub fn dir(value: Dir) -&gt; Attribute\n Specifies the text direction of the element.\nSynonyms:\nredraw/attribute.dir\nredraw/attribute dir","url":"redraw/attribute.html#dir"},{"doc":"redraw/attribute","title":"disabled","content":"pub fn disabled(is_disabled: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.disabled\nredraw/attribute disabled","url":"redraw/attribute.html#disabled"},{"doc":"redraw/attribute","title":"download","content":"pub fn download(filename: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.download\nredraw/attribute download","url":"redraw/attribute.html#download"},{"doc":"redraw/attribute","title":"draggable","content":"pub fn draggable(value: Bool) -&gt; Attribute\n Specifies whether the element is draggable. Part of HTML Drag and Drop API.\nSynonyms:\nredraw/attribute.draggable\nredraw/attribute draggable","url":"redraw/attribute.html#draggable"},{"doc":"redraw/attribute","title":"enctype","content":"pub fn enctype(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.enctype\nredraw/attribute enctype","url":"redraw/attribute.html#enctype"},{"doc":"redraw/attribute","title":"enter_key_hint","content":"pub fn enter_key_hint(value: String) -&gt; Attribute\n Specifies which action to present for the enter key on virtual keyboards.\nSynonyms:\nredraw/attribute.enter_key_hint\nredraw/attribute enter_key_hint","url":"redraw/attribute.html#enter_key_hint"},{"doc":"redraw/attribute","title":"for","content":"pub fn for(value: String) -&gt; Attribute\n For &lt;label&gt; and &lt;output&gt;, lets you associate the label with some control. Same as for HTML attribute. React uses the standard DOM property names (htmlFor) instead of HTML attribute names.\nSynonyms:\nredraw/attribute.for\nredraw/attribute for","url":"redraw/attribute.html#for"},{"doc":"redraw/attribute","title":"form_action","content":"pub fn form_action(action: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.form_action\nredraw/attribute form_action","url":"redraw/attribute.html#form_action"},{"doc":"redraw/attribute","title":"form_enctype","content":"pub fn form_enctype(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.form_enctype\nredraw/attribute form_enctype","url":"redraw/attribute.html#form_enctype"},{"doc":"redraw/attribute","title":"form_method","content":"pub fn form_method(method: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.form_method\nredraw/attribute form_method","url":"redraw/attribute.html#form_method"},{"doc":"redraw/attribute","title":"form_novalidate","content":"pub fn form_novalidate(value: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.form_novalidate\nredraw/attribute form_novalidate","url":"redraw/attribute.html#form_novalidate"},{"doc":"redraw/attribute","title":"form_target","content":"pub fn form_target(target: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.form_target\nredraw/attribute form_target","url":"redraw/attribute.html#form_target"},{"doc":"redraw/attribute","title":"height","content":"pub fn height(val: Int) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.height\nredraw/attribute height","url":"redraw/attribute.html#height"},{"doc":"redraw/attribute","title":"hidden","content":"pub fn hidden(value: Bool) -&gt; Attribute\n Specifies whether the element should be hidden.\nSynonyms:\nredraw/attribute.hidden\nredraw/attribute hidden","url":"redraw/attribute.html#hidden"},{"doc":"redraw/attribute","title":"href","content":"pub fn href(url: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.href\nredraw/attribute href","url":"redraw/attribute.html#href"},{"doc":"redraw/attribute","title":"html_for","content":"pub fn html_for(value: String) -&gt; Attribute\n Alias of `for`.\nSynonyms:\nredraw/attribute.html_for\nredraw/attribute html_for","url":"redraw/attribute.html#html_for"},{"doc":"redraw/attribute","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n Specifies a unique identifier for this element, which can be used to find it later or connect it with other elements. Generate it with useId to avoid clashes between multiple instances of the same component.\nSynonyms:\nredraw/attribute.id\nredraw/attribute id","url":"redraw/attribute.html#id"},{"doc":"redraw/attribute","title":"inner_html","content":"pub fn inner_html(html: String) -&gt; InnerHTML\n\nSynonyms:\nredraw/attribute.inner_html\nredraw/attribute inner_html","url":"redraw/attribute.html#inner_html"},{"doc":"redraw/attribute","title":"input_mode","content":"pub fn input_mode(value: String) -&gt; Attribute\n Specifies what kind of keyboard to display (for example, text, number or telephone).\nSynonyms:\nredraw/attribute.input_mode\nredraw/attribute input_mode","url":"redraw/attribute.html#input_mode"},{"doc":"redraw/attribute","title":"is","content":"pub fn is(value: String) -&gt; Attribute\n If specified, the component will behave like a custom element.\nSynonyms:\nredraw/attribute.is\nredraw/attribute is","url":"redraw/attribute.html#is"},{"doc":"redraw/attribute","title":"item_prop","content":"pub fn item_prop(value: String) -&gt; Attribute\n Specifies which property the element represents for structured data crawlers.\nSynonyms:\nredraw/attribute.item_prop\nredraw/attribute item_prop","url":"redraw/attribute.html#item_prop"},{"doc":"redraw/attribute","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n Specifies the language of the element.\nSynonyms:\nredraw/attribute.lang\nredraw/attribute lang","url":"redraw/attribute.html#lang"},{"doc":"redraw/attribute","title":"loop","content":"pub fn loop(should_loop: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.loop\nredraw/attribute loop","url":"redraw/attribute.html#loop"},{"doc":"redraw/attribute","title":"max","content":"pub fn max(val: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.max\nredraw/attribute max","url":"redraw/attribute.html#max"},{"doc":"redraw/attribute","title":"method","content":"pub fn method(method: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.method\nredraw/attribute method","url":"redraw/attribute.html#method"},{"doc":"redraw/attribute","title":"min","content":"pub fn min(val: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.min\nredraw/attribute min","url":"redraw/attribute.html#min"},{"doc":"redraw/attribute","title":"msg","content":"pub fn msg(uri: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.msg\nredraw/attribute msg","url":"redraw/attribute.html#msg"},{"doc":"redraw/attribute","title":"name","content":"pub fn name(name: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.name\nredraw/attribute name","url":"redraw/attribute.html#name"},{"doc":"redraw/attribute","title":"novalidate","content":"pub fn novalidate(value: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.novalidate\nredraw/attribute novalidate","url":"redraw/attribute.html#novalidate"},{"doc":"redraw/attribute","title":"open","content":"pub fn open(is_open: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.open\nredraw/attribute open","url":"redraw/attribute.html#open"},{"doc":"redraw/attribute","title":"pattern","content":"pub fn pattern(regex: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.pattern\nredraw/attribute pattern","url":"redraw/attribute.html#pattern"},{"doc":"redraw/attribute","title":"placeholder","content":"pub fn placeholder(text: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.placeholder\nredraw/attribute placeholder","url":"redraw/attribute.html#placeholder"},{"doc":"redraw/attribute","title":"readonly","content":"pub fn readonly(is_readonly: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.readonly\nredraw/attribute readonly","url":"redraw/attribute.html#readonly"},{"doc":"redraw/attribute","title":"ref","content":"pub fn ref(ref: Ref(Option(a))) -&gt; Attribute\n A ref object from `redraw.use_ref`. Your ref will be filled with the DOM\n element for this node. Contrarily to JS React, when using a Ref, you&#39;re\n forced to use an optional type here. Because when using this function, you\n want to get a reference from a real DOM node, meaning at the initialization\n of the reference, you won&#39;t have any data. Use `ref_` when you want full\n control over the ref you send to the Component.\nSynonyms:\nredraw/attribute.ref\nredraw/attribute ref","url":"redraw/attribute.html#ref"},{"doc":"redraw/attribute","title":"ref_","content":"pub fn ref_(ref: fn(a) -&gt; Nil) -&gt; Attribute\n A ref callback function. The callback will be provided with the DOM element for this node. Use this function to get control on the ref provided by the DOM node or the component.\nSynonyms:\nredraw/attribute.ref_\nredraw/attribute ref_","url":"redraw/attribute.html#ref_"},{"doc":"redraw/attribute","title":"rel","content":"pub fn rel(relationship: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.rel\nredraw/attribute rel","url":"redraw/attribute.html#rel"},{"doc":"redraw/attribute","title":"required","content":"pub fn required(is_required: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.required\nredraw/attribute required","url":"redraw/attribute.html#required"},{"doc":"redraw/attribute","title":"role","content":"pub fn role(value: String) -&gt; Attribute\n Specifies the element role explicitly for assistive technologies.\nSynonyms:\nredraw/attribute.role\nredraw/attribute role","url":"redraw/attribute.html#role"},{"doc":"redraw/attribute","title":"rows","content":"pub fn rows(val: Int) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.rows\nredraw/attribute rows","url":"redraw/attribute.html#rows"},{"doc":"redraw/attribute","title":"selected","content":"pub fn selected(is_selected: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.selected\nredraw/attribute selected","url":"redraw/attribute.html#selected"},{"doc":"redraw/attribute","title":"slot","content":"pub fn slot(value: String) -&gt; Attribute\n Specifies the slot name when using shadow DOM.\nSynonyms:\nredraw/attribute.slot\nredraw/attribute slot","url":"redraw/attribute.html#slot"},{"doc":"redraw/attribute","title":"spell_check","content":"pub fn spell_check(value: Bool) -&gt; Attribute\n If explicitly set to true or false, enables or disables spellchecking.\nSynonyms:\nredraw/attribute.spell_check\nredraw/attribute spell_check","url":"redraw/attribute.html#spell_check"},{"doc":"redraw/attribute","title":"src","content":"pub fn src(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.src\nredraw/attribute src","url":"redraw/attribute.html#src"},{"doc":"redraw/attribute","title":"step","content":"pub fn step(val: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.step\nredraw/attribute step","url":"redraw/attribute.html#step"},{"doc":"redraw/attribute","title":"style","content":"pub fn style(styles: List(#(String, String))) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.style\nredraw/attribute style","url":"redraw/attribute.html#style"},{"doc":"redraw/attribute","title":"suppress_content_editable_warning","content":"pub fn suppress_content_editable_warning(\n  value: Bool,\n) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.suppress_content_editable_warning\nredraw/attribute suppress_content_editable_warning","url":"redraw/attribute.html#suppress_content_editable_warning"},{"doc":"redraw/attribute","title":"suppress_hydration_warning","content":"pub fn suppress_hydration_warning(value: Bool) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.suppress_hydration_warning\nredraw/attribute suppress_hydration_warning","url":"redraw/attribute.html#suppress_hydration_warning"},{"doc":"redraw/attribute","title":"tab_index","content":"pub fn tab_index(value: Int) -&gt; Attribute\n Overrides the default Tab button behavior. Avoid using values other than -1 and 0.\nSynonyms:\nredraw/attribute.tab_index\nredraw/attribute tab_index","url":"redraw/attribute.html#tab_index"},{"doc":"redraw/attribute","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.target\nredraw/attribute target","url":"redraw/attribute.html#target"},{"doc":"redraw/attribute","title":"title","content":"pub fn title(value: String) -&gt; Attribute\n Specifies the tooltip text for the element.\nSynonyms:\nredraw/attribute.title\nredraw/attribute title","url":"redraw/attribute.html#title"},{"doc":"redraw/attribute","title":"translate","content":"pub fn translate(value: Translate) -&gt; Attribute\n Passing No excludes the element content from being translated.\nSynonyms:\nredraw/attribute.translate\nredraw/attribute translate","url":"redraw/attribute.html#translate"},{"doc":"redraw/attribute","title":"type_","content":"pub fn type_(name: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.type_\nredraw/attribute type_","url":"redraw/attribute.html#type_"},{"doc":"redraw/attribute","title":"value","content":"pub fn value(val: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.value\nredraw/attribute value","url":"redraw/attribute.html#value"},{"doc":"redraw/attribute","title":"width","content":"pub fn width(val: Int) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.width\nredraw/attribute width","url":"redraw/attribute.html#width"},{"doc":"redraw/attribute","title":"wrap","content":"pub fn wrap(mode: String) -&gt; Attribute\n\nSynonyms:\nredraw/attribute.wrap\nredraw/attribute wrap","url":"redraw/attribute.html#wrap"},{"doc":"redraw/attribute","title":"redraw/attribute","content":"","url":"redraw/attribute.html"},{"doc":"redraw/event","title":"Event","content":"pub type Event\n\n\nSynonyms:\nredraw/event.Event\nredraw/event Event","url":"redraw/event.html#Event"},{"doc":"redraw/event","title":"bubbles","content":"pub fn bubbles(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.bubbles\nredraw/event bubbles","url":"redraw/event.html#bubbles"},{"doc":"redraw/event","title":"cancelable","content":"pub fn cancelable(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.cancelable\nredraw/event cancelable","url":"redraw/event.html#cancelable"},{"doc":"redraw/event","title":"current_target","content":"pub fn current_target(event: Event) -&gt; Dynamic\n\nSynonyms:\nredraw/event.current_target\nredraw/event current_target","url":"redraw/event.html#current_target"},{"doc":"redraw/event","title":"default_prevented","content":"pub fn default_prevented(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.default_prevented\nredraw/event default_prevented","url":"redraw/event.html#default_prevented"},{"doc":"redraw/event","title":"event_phase","content":"pub fn event_phase(event: Event) -&gt; Int\n\nSynonyms:\nredraw/event.event_phase\nredraw/event event_phase","url":"redraw/event.html#event_phase"},{"doc":"redraw/event","title":"is_default_prevented","content":"pub fn is_default_prevented(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.is_default_prevented\nredraw/event is_default_prevented","url":"redraw/event.html#is_default_prevented"},{"doc":"redraw/event","title":"is_persistent","content":"pub fn is_persistent(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.is_persistent\nredraw/event is_persistent","url":"redraw/event.html#is_persistent"},{"doc":"redraw/event","title":"is_propagation_stopped","content":"pub fn is_propagation_stopped(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.is_propagation_stopped\nredraw/event is_propagation_stopped","url":"redraw/event.html#is_propagation_stopped"},{"doc":"redraw/event","title":"is_trusted","content":"pub fn is_trusted(event: Event) -&gt; Bool\n\nSynonyms:\nredraw/event.is_trusted\nredraw/event is_trusted","url":"redraw/event.html#is_trusted"},{"doc":"redraw/event","title":"native_event","content":"pub fn native_event(event: Event) -&gt; Dynamic\n\nSynonyms:\nredraw/event.native_event\nredraw/event native_event","url":"redraw/event.html#native_event"},{"doc":"redraw/event","title":"persist","content":"pub fn persist(event: Event) -&gt; Event\n\nSynonyms:\nredraw/event.persist\nredraw/event persist","url":"redraw/event.html#persist"},{"doc":"redraw/event","title":"prevent_default","content":"pub fn prevent_default(event: Event) -&gt; Event\n\nSynonyms:\nredraw/event.prevent_default\nredraw/event prevent_default","url":"redraw/event.html#prevent_default"},{"doc":"redraw/event","title":"stop_propagation","content":"pub fn stop_propagation(event: Event) -&gt; Event\n\nSynonyms:\nredraw/event.stop_propagation\nredraw/event stop_propagation","url":"redraw/event.html#stop_propagation"},{"doc":"redraw/event","title":"target","content":"pub fn target(event: Event) -&gt; Dynamic\n\nSynonyms:\nredraw/event.target\nredraw/event target","url":"redraw/event.html#target"},{"doc":"redraw/event","title":"time_stamp","content":"pub fn time_stamp(event: Event) -&gt; Int\n\nSynonyms:\nredraw/event.time_stamp\nredraw/event time_stamp","url":"redraw/event.html#time_stamp"},{"doc":"redraw/event","title":"redraw/event","content":"","url":"redraw/event.html"},{"doc":"redraw/event/animation","title":"AnimationEvent","content":"pub type AnimationEvent\n\n\nSynonyms:\nredraw/event/animation.AnimationEvent\nredraw/event/animation AnimationEvent","url":"redraw/event/animation.html#AnimationEvent"},{"doc":"redraw/event/animation","title":"animation_name","content":"pub fn animation_name(event: AnimationEvent) -&gt; String\n\nSynonyms:\nredraw/event/animation.animation_name\nredraw/event/animation animation_name","url":"redraw/event/animation.html#animation_name"},{"doc":"redraw/event/animation","title":"as_event","content":"pub fn as_event(event: AnimationEvent) -&gt; Event\n\nSynonyms:\nredraw/event/animation.as_event\nredraw/event/animation as_event","url":"redraw/event/animation.html#as_event"},{"doc":"redraw/event/animation","title":"elapsed_time","content":"pub fn elapsed_time(event: AnimationEvent) -&gt; Float\n\nSynonyms:\nredraw/event/animation.elapsed_time\nredraw/event/animation elapsed_time","url":"redraw/event/animation.html#elapsed_time"},{"doc":"redraw/event/animation","title":"pseudo_element","content":"pub fn pseudo_element(event: AnimationEvent) -&gt; String\n\nSynonyms:\nredraw/event/animation.pseudo_element\nredraw/event/animation pseudo_element","url":"redraw/event/animation.html#pseudo_element"},{"doc":"redraw/event/animation","title":"redraw/event/animation","content":"","url":"redraw/event/animation.html"},{"doc":"redraw/event/clipboard","title":"ClipboardEvent","content":"pub type ClipboardEvent\n\n\nSynonyms:\nredraw/event/clipboard.ClipboardEvent\nredraw/event/clipboard ClipboardEvent","url":"redraw/event/clipboard.html#ClipboardEvent"},{"doc":"redraw/event/clipboard","title":"as_event","content":"pub fn as_event(event: ClipboardEvent) -&gt; Event\n\nSynonyms:\nredraw/event/clipboard.as_event\nredraw/event/clipboard as_event","url":"redraw/event/clipboard.html#as_event"},{"doc":"redraw/event/clipboard","title":"clipboard_data","content":"pub fn clipboard_data(event: ClipboardEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/clipboard.clipboard_data\nredraw/event/clipboard clipboard_data","url":"redraw/event/clipboard.html#clipboard_data"},{"doc":"redraw/event/clipboard","title":"redraw/event/clipboard","content":"","url":"redraw/event/clipboard.html"},{"doc":"redraw/event/composition","title":"CompositionEvent","content":"pub type CompositionEvent\n\n\nSynonyms:\nredraw/event/composition.CompositionEvent\nredraw/event/composition CompositionEvent","url":"redraw/event/composition.html#CompositionEvent"},{"doc":"redraw/event/composition","title":"as_event","content":"pub fn as_event(event: CompositionEvent) -&gt; Event\n\nSynonyms:\nredraw/event/composition.as_event\nredraw/event/composition as_event","url":"redraw/event/composition.html#as_event"},{"doc":"redraw/event/composition","title":"data","content":"pub fn data(event: CompositionEvent) -&gt; String\n\nSynonyms:\nredraw/event/composition.data\nredraw/event/composition data","url":"redraw/event/composition.html#data"},{"doc":"redraw/event/composition","title":"redraw/event/composition","content":"","url":"redraw/event/composition.html"},{"doc":"redraw/event/ui","title":"UIEvent","content":"pub type UIEvent\n\n\nSynonyms:\nredraw/event/ui.UIEvent\nredraw/event/ui UIEvent","url":"redraw/event/ui.html#UIEvent"},{"doc":"redraw/event/ui","title":"as_event","content":"pub fn as_event(event: UIEvent) -&gt; Event\n\nSynonyms:\nredraw/event/ui.as_event\nredraw/event/ui as_event","url":"redraw/event/ui.html#as_event"},{"doc":"redraw/event/ui","title":"detail","content":"pub fn detail(event: UIEvent) -&gt; Int\n\nSynonyms:\nredraw/event/ui.detail\nredraw/event/ui detail","url":"redraw/event/ui.html#detail"},{"doc":"redraw/event/ui","title":"view","content":"pub fn view(event: UIEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/ui.view\nredraw/event/ui view","url":"redraw/event/ui.html#view"},{"doc":"redraw/event/ui","title":"redraw/event/ui","content":"","url":"redraw/event/ui.html"},{"doc":"redraw/event/mouse","title":"MouseEvent","content":"pub type MouseEvent\n\n\nSynonyms:\nredraw/event/mouse.MouseEvent\nredraw/event/mouse MouseEvent","url":"redraw/event/mouse.html#MouseEvent"},{"doc":"redraw/event/mouse","title":"alt_key","content":"pub fn alt_key(event: MouseEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/mouse.alt_key\nredraw/event/mouse alt_key","url":"redraw/event/mouse.html#alt_key"},{"doc":"redraw/event/mouse","title":"as_event","content":"pub fn as_event(event: MouseEvent) -&gt; Event\n\nSynonyms:\nredraw/event/mouse.as_event\nredraw/event/mouse as_event","url":"redraw/event/mouse.html#as_event"},{"doc":"redraw/event/mouse","title":"as_ui_event","content":"pub fn as_ui_event(event: MouseEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/mouse.as_ui_event\nredraw/event/mouse as_ui_event","url":"redraw/event/mouse.html#as_ui_event"},{"doc":"redraw/event/mouse","title":"button","content":"pub fn button(event: MouseEvent) -&gt; Int\n\nSynonyms:\nredraw/event/mouse.button\nredraw/event/mouse button","url":"redraw/event/mouse.html#button"},{"doc":"redraw/event/mouse","title":"buttons","content":"pub fn buttons(event: MouseEvent) -&gt; Int\n\nSynonyms:\nredraw/event/mouse.buttons\nredraw/event/mouse buttons","url":"redraw/event/mouse.html#buttons"},{"doc":"redraw/event/mouse","title":"client_x","content":"pub fn client_x(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.client_x\nredraw/event/mouse client_x","url":"redraw/event/mouse.html#client_x"},{"doc":"redraw/event/mouse","title":"client_y","content":"pub fn client_y(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.client_y\nredraw/event/mouse client_y","url":"redraw/event/mouse.html#client_y"},{"doc":"redraw/event/mouse","title":"clipboard_data","content":"pub fn clipboard_data(event: MouseEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/mouse.clipboard_data\nredraw/event/mouse clipboard_data","url":"redraw/event/mouse.html#clipboard_data"},{"doc":"redraw/event/mouse","title":"ctrl_key","content":"pub fn ctrl_key(event: MouseEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/mouse.ctrl_key\nredraw/event/mouse ctrl_key","url":"redraw/event/mouse.html#ctrl_key"},{"doc":"redraw/event/mouse","title":"get_modifier_state","content":"pub fn get_modifier_state(event: MouseEvent, key: String) -&gt; Bool\n\nSynonyms:\nredraw/event/mouse.get_modifier_state\nredraw/event/mouse get_modifier_state","url":"redraw/event/mouse.html#get_modifier_state"},{"doc":"redraw/event/mouse","title":"meta_key","content":"pub fn meta_key(event: MouseEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/mouse.meta_key\nredraw/event/mouse meta_key","url":"redraw/event/mouse.html#meta_key"},{"doc":"redraw/event/mouse","title":"movement_x","content":"pub fn movement_x(event: MouseEvent) -&gt; Int\n\nSynonyms:\nredraw/event/mouse.movement_x\nredraw/event/mouse movement_x","url":"redraw/event/mouse.html#movement_x"},{"doc":"redraw/event/mouse","title":"movement_y","content":"pub fn movement_y(event: MouseEvent) -&gt; Int\n\nSynonyms:\nredraw/event/mouse.movement_y\nredraw/event/mouse movement_y","url":"redraw/event/mouse.html#movement_y"},{"doc":"redraw/event/mouse","title":"page_x","content":"pub fn page_x(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.page_x\nredraw/event/mouse page_x","url":"redraw/event/mouse.html#page_x"},{"doc":"redraw/event/mouse","title":"page_y","content":"pub fn page_y(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.page_y\nredraw/event/mouse page_y","url":"redraw/event/mouse.html#page_y"},{"doc":"redraw/event/mouse","title":"related_target","content":"pub fn related_target(event: MouseEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/mouse.related_target\nredraw/event/mouse related_target","url":"redraw/event/mouse.html#related_target"},{"doc":"redraw/event/mouse","title":"screen_x","content":"pub fn screen_x(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.screen_x\nredraw/event/mouse screen_x","url":"redraw/event/mouse.html#screen_x"},{"doc":"redraw/event/mouse","title":"screen_y","content":"pub fn screen_y(event: MouseEvent) -&gt; Float\n\nSynonyms:\nredraw/event/mouse.screen_y\nredraw/event/mouse screen_y","url":"redraw/event/mouse.html#screen_y"},{"doc":"redraw/event/mouse","title":"shift_key","content":"pub fn shift_key(event: MouseEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/mouse.shift_key\nredraw/event/mouse shift_key","url":"redraw/event/mouse.html#shift_key"},{"doc":"redraw/event/mouse","title":"redraw/event/mouse","content":"","url":"redraw/event/mouse.html"},{"doc":"redraw/event/drag","title":"DragEvent","content":"pub type DragEvent\n\n\nSynonyms:\nredraw/event/drag.DragEvent\nredraw/event/drag DragEvent","url":"redraw/event/drag.html#DragEvent"},{"doc":"redraw/event/drag","title":"as_event","content":"pub fn as_event(event: DragEvent) -&gt; Event\n\nSynonyms:\nredraw/event/drag.as_event\nredraw/event/drag as_event","url":"redraw/event/drag.html#as_event"},{"doc":"redraw/event/drag","title":"as_mouse_event","content":"pub fn as_mouse_event(event: DragEvent) -&gt; MouseEvent\n\nSynonyms:\nredraw/event/drag.as_mouse_event\nredraw/event/drag as_mouse_event","url":"redraw/event/drag.html#as_mouse_event"},{"doc":"redraw/event/drag","title":"as_ui_event","content":"pub fn as_ui_event(event: DragEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/drag.as_ui_event\nredraw/event/drag as_ui_event","url":"redraw/event/drag.html#as_ui_event"},{"doc":"redraw/event/drag","title":"data_transfer","content":"pub fn data_transfer(event: DragEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/drag.data_transfer\nredraw/event/drag data_transfer","url":"redraw/event/drag.html#data_transfer"},{"doc":"redraw/event/drag","title":"redraw/event/drag","content":"","url":"redraw/event/drag.html"},{"doc":"redraw/event/focus","title":"FocusEvent","content":"pub type FocusEvent\n\n\nSynonyms:\nredraw/event/focus.FocusEvent\nredraw/event/focus FocusEvent","url":"redraw/event/focus.html#FocusEvent"},{"doc":"redraw/event/focus","title":"as_event","content":"pub fn as_event(event: FocusEvent) -&gt; Event\n\nSynonyms:\nredraw/event/focus.as_event\nredraw/event/focus as_event","url":"redraw/event/focus.html#as_event"},{"doc":"redraw/event/focus","title":"as_ui_event","content":"pub fn as_ui_event(event: FocusEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/focus.as_ui_event\nredraw/event/focus as_ui_event","url":"redraw/event/focus.html#as_ui_event"},{"doc":"redraw/event/focus","title":"related_target","content":"pub fn related_target(event: FocusEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/focus.related_target\nredraw/event/focus related_target","url":"redraw/event/focus.html#related_target"},{"doc":"redraw/event/focus","title":"redraw/event/focus","content":"","url":"redraw/event/focus.html"},{"doc":"redraw/event/input","title":"InputEvent","content":"pub type InputEvent\n\n\nSynonyms:\nredraw/event/input.InputEvent\nredraw/event/input InputEvent","url":"redraw/event/input.html#InputEvent"},{"doc":"redraw/event/input","title":"as_event","content":"pub fn as_event(event: InputEvent) -&gt; Event\n\nSynonyms:\nredraw/event/input.as_event\nredraw/event/input as_event","url":"redraw/event/input.html#as_event"},{"doc":"redraw/event/input","title":"data","content":"pub fn data(event: InputEvent) -&gt; String\n\nSynonyms:\nredraw/event/input.data\nredraw/event/input data","url":"redraw/event/input.html#data"},{"doc":"redraw/event/input","title":"redraw/event/input","content":"","url":"redraw/event/input.html"},{"doc":"redraw/event/keyboard","title":"KeyboardEvent","content":"pub type KeyboardEvent\n\n\nSynonyms:\nredraw/event/keyboard.KeyboardEvent\nredraw/event/keyboard KeyboardEvent","url":"redraw/event/keyboard.html#KeyboardEvent"},{"doc":"redraw/event/keyboard","title":"alt_key","content":"pub fn alt_key(event: KeyboardEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.alt_key\nredraw/event/keyboard alt_key","url":"redraw/event/keyboard.html#alt_key"},{"doc":"redraw/event/keyboard","title":"as_event","content":"pub fn as_event(event: KeyboardEvent) -&gt; Event\n\nSynonyms:\nredraw/event/keyboard.as_event\nredraw/event/keyboard as_event","url":"redraw/event/keyboard.html#as_event"},{"doc":"redraw/event/keyboard","title":"as_ui_event","content":"pub fn as_ui_event(event: KeyboardEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/keyboard.as_ui_event\nredraw/event/keyboard as_ui_event","url":"redraw/event/keyboard.html#as_ui_event"},{"doc":"redraw/event/keyboard","title":"char_code","content":"pub fn char_code(event: KeyboardEvent) -&gt; Int\n\nSynonyms:\nredraw/event/keyboard.char_code\nredraw/event/keyboard char_code","url":"redraw/event/keyboard.html#char_code"},{"doc":"redraw/event/keyboard","title":"code","content":"pub fn code(event: KeyboardEvent) -&gt; String\n\nSynonyms:\nredraw/event/keyboard.code\nredraw/event/keyboard code","url":"redraw/event/keyboard.html#code"},{"doc":"redraw/event/keyboard","title":"ctrl_key","content":"pub fn ctrl_key(event: KeyboardEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.ctrl_key\nredraw/event/keyboard ctrl_key","url":"redraw/event/keyboard.html#ctrl_key"},{"doc":"redraw/event/keyboard","title":"get_modifier_state","content":"pub fn get_modifier_state(\n  event: KeyboardEvent,\n  key: String,\n) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.get_modifier_state\nredraw/event/keyboard get_modifier_state","url":"redraw/event/keyboard.html#get_modifier_state"},{"doc":"redraw/event/keyboard","title":"key","content":"pub fn key(event: KeyboardEvent) -&gt; String\n\nSynonyms:\nredraw/event/keyboard.key\nredraw/event/keyboard key","url":"redraw/event/keyboard.html#key"},{"doc":"redraw/event/keyboard","title":"key_code","content":"pub fn key_code(event: KeyboardEvent) -&gt; Int\n\nSynonyms:\nredraw/event/keyboard.key_code\nredraw/event/keyboard key_code","url":"redraw/event/keyboard.html#key_code"},{"doc":"redraw/event/keyboard","title":"locale","content":"pub fn locale(event: KeyboardEvent) -&gt; String\n\nSynonyms:\nredraw/event/keyboard.locale\nredraw/event/keyboard locale","url":"redraw/event/keyboard.html#locale"},{"doc":"redraw/event/keyboard","title":"location","content":"pub fn location(event: KeyboardEvent) -&gt; Float\n\nSynonyms:\nredraw/event/keyboard.location\nredraw/event/keyboard location","url":"redraw/event/keyboard.html#location"},{"doc":"redraw/event/keyboard","title":"meta_key","content":"pub fn meta_key(event: KeyboardEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.meta_key\nredraw/event/keyboard meta_key","url":"redraw/event/keyboard.html#meta_key"},{"doc":"redraw/event/keyboard","title":"repeat","content":"pub fn repeat(event: KeyboardEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.repeat\nredraw/event/keyboard repeat","url":"redraw/event/keyboard.html#repeat"},{"doc":"redraw/event/keyboard","title":"shift_key","content":"pub fn shift_key(event: KeyboardEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/keyboard.shift_key\nredraw/event/keyboard shift_key","url":"redraw/event/keyboard.html#shift_key"},{"doc":"redraw/event/keyboard","title":"which","content":"pub fn which(event: KeyboardEvent) -&gt; Int\n\nSynonyms:\nredraw/event/keyboard.which\nredraw/event/keyboard which","url":"redraw/event/keyboard.html#which"},{"doc":"redraw/event/keyboard","title":"redraw/event/keyboard","content":"","url":"redraw/event/keyboard.html"},{"doc":"redraw/event/pointer","title":"PointerEvent","content":"pub type PointerEvent\n\n\nSynonyms:\nredraw/event/pointer.PointerEvent\nredraw/event/pointer PointerEvent","url":"redraw/event/pointer.html#PointerEvent"},{"doc":"redraw/event/pointer","title":"as_event","content":"pub fn as_event(event: PointerEvent) -&gt; Event\n\nSynonyms:\nredraw/event/pointer.as_event\nredraw/event/pointer as_event","url":"redraw/event/pointer.html#as_event"},{"doc":"redraw/event/pointer","title":"as_mouse_event","content":"pub fn as_mouse_event(event: PointerEvent) -&gt; MouseEvent\n\nSynonyms:\nredraw/event/pointer.as_mouse_event\nredraw/event/pointer as_mouse_event","url":"redraw/event/pointer.html#as_mouse_event"},{"doc":"redraw/event/pointer","title":"as_ui_event","content":"pub fn as_ui_event(event: PointerEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/pointer.as_ui_event\nredraw/event/pointer as_ui_event","url":"redraw/event/pointer.html#as_ui_event"},{"doc":"redraw/event/pointer","title":"height","content":"pub fn height(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.height\nredraw/event/pointer height","url":"redraw/event/pointer.html#height"},{"doc":"redraw/event/pointer","title":"is_primary","content":"pub fn is_primary(event: PointerEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/pointer.is_primary\nredraw/event/pointer is_primary","url":"redraw/event/pointer.html#is_primary"},{"doc":"redraw/event/pointer","title":"pointer_id","content":"pub fn pointer_id(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.pointer_id\nredraw/event/pointer pointer_id","url":"redraw/event/pointer.html#pointer_id"},{"doc":"redraw/event/pointer","title":"pointer_type","content":"pub fn pointer_type(event: PointerEvent) -&gt; String\n\nSynonyms:\nredraw/event/pointer.pointer_type\nredraw/event/pointer pointer_type","url":"redraw/event/pointer.html#pointer_type"},{"doc":"redraw/event/pointer","title":"pressure","content":"pub fn pressure(event: PointerEvent) -&gt; Float\n\nSynonyms:\nredraw/event/pointer.pressure\nredraw/event/pointer pressure","url":"redraw/event/pointer.html#pressure"},{"doc":"redraw/event/pointer","title":"tangential_pressure","content":"pub fn tangential_pressure(event: PointerEvent) -&gt; Float\n\nSynonyms:\nredraw/event/pointer.tangential_pressure\nredraw/event/pointer tangential_pressure","url":"redraw/event/pointer.html#tangential_pressure"},{"doc":"redraw/event/pointer","title":"tilt_x","content":"pub fn tilt_x(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.tilt_x\nredraw/event/pointer tilt_x","url":"redraw/event/pointer.html#tilt_x"},{"doc":"redraw/event/pointer","title":"tilt_y","content":"pub fn tilt_y(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.tilt_y\nredraw/event/pointer tilt_y","url":"redraw/event/pointer.html#tilt_y"},{"doc":"redraw/event/pointer","title":"twist","content":"pub fn twist(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.twist\nredraw/event/pointer twist","url":"redraw/event/pointer.html#twist"},{"doc":"redraw/event/pointer","title":"width","content":"pub fn width(event: PointerEvent) -&gt; Int\n\nSynonyms:\nredraw/event/pointer.width\nredraw/event/pointer width","url":"redraw/event/pointer.html#width"},{"doc":"redraw/event/pointer","title":"redraw/event/pointer","content":"","url":"redraw/event/pointer.html"},{"doc":"redraw/event/touch","title":"TouchEvent","content":"pub type TouchEvent\n\n\nSynonyms:\nredraw/event/touch.TouchEvent\nredraw/event/touch TouchEvent","url":"redraw/event/touch.html#TouchEvent"},{"doc":"redraw/event/touch","title":"alt_key","content":"pub fn alt_key(event: TouchEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/touch.alt_key\nredraw/event/touch alt_key","url":"redraw/event/touch.html#alt_key"},{"doc":"redraw/event/touch","title":"as_event","content":"pub fn as_event(event: TouchEvent) -&gt; Event\n\nSynonyms:\nredraw/event/touch.as_event\nredraw/event/touch as_event","url":"redraw/event/touch.html#as_event"},{"doc":"redraw/event/touch","title":"as_ui_event","content":"pub fn as_ui_event(event: TouchEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/touch.as_ui_event\nredraw/event/touch as_ui_event","url":"redraw/event/touch.html#as_ui_event"},{"doc":"redraw/event/touch","title":"changed_touches","content":"pub fn changed_touches(event: TouchEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/touch.changed_touches\nredraw/event/touch changed_touches","url":"redraw/event/touch.html#changed_touches"},{"doc":"redraw/event/touch","title":"ctrl_key","content":"pub fn ctrl_key(event: TouchEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/touch.ctrl_key\nredraw/event/touch ctrl_key","url":"redraw/event/touch.html#ctrl_key"},{"doc":"redraw/event/touch","title":"get_modifier_state","content":"pub fn get_modifier_state(event: TouchEvent, key: String) -&gt; Bool\n\nSynonyms:\nredraw/event/touch.get_modifier_state\nredraw/event/touch get_modifier_state","url":"redraw/event/touch.html#get_modifier_state"},{"doc":"redraw/event/touch","title":"meta_key","content":"pub fn meta_key(event: TouchEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/touch.meta_key\nredraw/event/touch meta_key","url":"redraw/event/touch.html#meta_key"},{"doc":"redraw/event/touch","title":"shift_key","content":"pub fn shift_key(event: TouchEvent) -&gt; Bool\n\nSynonyms:\nredraw/event/touch.shift_key\nredraw/event/touch shift_key","url":"redraw/event/touch.html#shift_key"},{"doc":"redraw/event/touch","title":"target_touches","content":"pub fn target_touches(event: TouchEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/touch.target_touches\nredraw/event/touch target_touches","url":"redraw/event/touch.html#target_touches"},{"doc":"redraw/event/touch","title":"touches","content":"pub fn touches(event: TouchEvent) -&gt; Dynamic\n\nSynonyms:\nredraw/event/touch.touches\nredraw/event/touch touches","url":"redraw/event/touch.html#touches"},{"doc":"redraw/event/touch","title":"redraw/event/touch","content":"","url":"redraw/event/touch.html"},{"doc":"redraw/event/transition","title":"TransitionEvent","content":"pub type TransitionEvent\n\n\nSynonyms:\nredraw/event/transition.TransitionEvent\nredraw/event/transition TransitionEvent","url":"redraw/event/transition.html#TransitionEvent"},{"doc":"redraw/event/transition","title":"as_event","content":"pub fn as_event(event: TransitionEvent) -&gt; Event\n\nSynonyms:\nredraw/event/transition.as_event\nredraw/event/transition as_event","url":"redraw/event/transition.html#as_event"},{"doc":"redraw/event/transition","title":"elapsed_time","content":"pub fn elapsed_time(event: TransitionEvent) -&gt; Int\n\nSynonyms:\nredraw/event/transition.elapsed_time\nredraw/event/transition elapsed_time","url":"redraw/event/transition.html#elapsed_time"},{"doc":"redraw/event/transition","title":"property_name","content":"pub fn property_name(event: TransitionEvent) -&gt; String\n\nSynonyms:\nredraw/event/transition.property_name\nredraw/event/transition property_name","url":"redraw/event/transition.html#property_name"},{"doc":"redraw/event/transition","title":"pseudo_element","content":"pub fn pseudo_element(event: TransitionEvent) -&gt; String\n\nSynonyms:\nredraw/event/transition.pseudo_element\nredraw/event/transition pseudo_element","url":"redraw/event/transition.html#pseudo_element"},{"doc":"redraw/event/transition","title":"redraw/event/transition","content":"","url":"redraw/event/transition.html"},{"doc":"redraw/event/wheel","title":"WheelEvent","content":"pub type WheelEvent\n\n\nSynonyms:\nredraw/event/wheel.WheelEvent\nredraw/event/wheel WheelEvent","url":"redraw/event/wheel.html#WheelEvent"},{"doc":"redraw/event/wheel","title":"as_event","content":"pub fn as_event(event: WheelEvent) -&gt; Event\n\nSynonyms:\nredraw/event/wheel.as_event\nredraw/event/wheel as_event","url":"redraw/event/wheel.html#as_event"},{"doc":"redraw/event/wheel","title":"as_mouse_event","content":"pub fn as_mouse_event(event: WheelEvent) -&gt; MouseEvent\n\nSynonyms:\nredraw/event/wheel.as_mouse_event\nredraw/event/wheel as_mouse_event","url":"redraw/event/wheel.html#as_mouse_event"},{"doc":"redraw/event/wheel","title":"as_ui_event","content":"pub fn as_ui_event(event: WheelEvent) -&gt; UIEvent\n\nSynonyms:\nredraw/event/wheel.as_ui_event\nredraw/event/wheel as_ui_event","url":"redraw/event/wheel.html#as_ui_event"},{"doc":"redraw/event/wheel","title":"delta_mode","content":"pub fn delta_mode(event: WheelEvent) -&gt; Int\n\nSynonyms:\nredraw/event/wheel.delta_mode\nredraw/event/wheel delta_mode","url":"redraw/event/wheel.html#delta_mode"},{"doc":"redraw/event/wheel","title":"delta_x","content":"pub fn delta_x(event: WheelEvent) -&gt; Float\n\nSynonyms:\nredraw/event/wheel.delta_x\nredraw/event/wheel delta_x","url":"redraw/event/wheel.html#delta_x"},{"doc":"redraw/event/wheel","title":"delta_y","content":"pub fn delta_y(event: WheelEvent) -&gt; Float\n\nSynonyms:\nredraw/event/wheel.delta_y\nredraw/event/wheel delta_y","url":"redraw/event/wheel.html#delta_y"},{"doc":"redraw/event/wheel","title":"delta_z","content":"pub fn delta_z(event: WheelEvent) -&gt; Float\n\nSynonyms:\nredraw/event/wheel.delta_z\nredraw/event/wheel delta_z","url":"redraw/event/wheel.html#delta_z"},{"doc":"redraw/event/wheel","title":"redraw/event/wheel","content":"","url":"redraw/event/wheel.html"},{"doc":"redraw/handler","title":"on_abort","content":"pub fn on_abort(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_abort\nredraw/handler on_abort","url":"redraw/handler.html#on_abort"},{"doc":"redraw/handler","title":"on_abort_capture","content":"pub fn on_abort_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_abort_capture\nredraw/handler on_abort_capture","url":"redraw/handler.html#on_abort_capture"},{"doc":"redraw/handler","title":"on_animation_end","content":"pub fn on_animation_end(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_end\nredraw/handler on_animation_end","url":"redraw/handler.html#on_animation_end"},{"doc":"redraw/handler","title":"on_animation_end_capture","content":"pub fn on_animation_end_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_end_capture\nredraw/handler on_animation_end_capture","url":"redraw/handler.html#on_animation_end_capture"},{"doc":"redraw/handler","title":"on_animation_iteration","content":"pub fn on_animation_iteration(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_iteration\nredraw/handler on_animation_iteration","url":"redraw/handler.html#on_animation_iteration"},{"doc":"redraw/handler","title":"on_animation_iteration_capture","content":"pub fn on_animation_iteration_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_iteration_capture\nredraw/handler on_animation_iteration_capture","url":"redraw/handler.html#on_animation_iteration_capture"},{"doc":"redraw/handler","title":"on_animation_start","content":"pub fn on_animation_start(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_start\nredraw/handler on_animation_start","url":"redraw/handler.html#on_animation_start"},{"doc":"redraw/handler","title":"on_animation_start_capture","content":"pub fn on_animation_start_capture(\n  handler: fn(AnimationEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_animation_start_capture\nredraw/handler on_animation_start_capture","url":"redraw/handler.html#on_animation_start_capture"},{"doc":"redraw/handler","title":"on_aux_click","content":"pub fn on_aux_click(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_aux_click\nredraw/handler on_aux_click","url":"redraw/handler.html#on_aux_click"},{"doc":"redraw/handler","title":"on_aux_click_capture","content":"pub fn on_aux_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_aux_click_capture\nredraw/handler on_aux_click_capture","url":"redraw/handler.html#on_aux_click_capture"},{"doc":"redraw/handler","title":"on_before_input","content":"pub fn on_before_input(\n  handler: fn(InputEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_before_input\nredraw/handler on_before_input","url":"redraw/handler.html#on_before_input"},{"doc":"redraw/handler","title":"on_before_input_capture","content":"pub fn on_before_input_capture(\n  handler: fn(InputEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_before_input_capture\nredraw/handler on_before_input_capture","url":"redraw/handler.html#on_before_input_capture"},{"doc":"redraw/handler","title":"on_blur","content":"pub fn on_blur(handler: fn(FocusEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_blur\nredraw/handler on_blur","url":"redraw/handler.html#on_blur"},{"doc":"redraw/handler","title":"on_blur_capture","content":"pub fn on_blur_capture(\n  handler: fn(FocusEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_blur_capture\nredraw/handler on_blur_capture","url":"redraw/handler.html#on_blur_capture"},{"doc":"redraw/handler","title":"on_can_play","content":"pub fn on_can_play(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_can_play\nredraw/handler on_can_play","url":"redraw/handler.html#on_can_play"},{"doc":"redraw/handler","title":"on_can_play_capture","content":"pub fn on_can_play_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_can_play_capture\nredraw/handler on_can_play_capture","url":"redraw/handler.html#on_can_play_capture"},{"doc":"redraw/handler","title":"on_can_play_through","content":"pub fn on_can_play_through(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_can_play_through\nredraw/handler on_can_play_through","url":"redraw/handler.html#on_can_play_through"},{"doc":"redraw/handler","title":"on_can_play_through_capture","content":"pub fn on_can_play_through_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_can_play_through_capture\nredraw/handler on_can_play_through_capture","url":"redraw/handler.html#on_can_play_through_capture"},{"doc":"redraw/handler","title":"on_cancel","content":"pub fn on_cancel(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_cancel\nredraw/handler on_cancel","url":"redraw/handler.html#on_cancel"},{"doc":"redraw/handler","title":"on_cancel_capture","content":"pub fn on_cancel_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_cancel_capture\nredraw/handler on_cancel_capture","url":"redraw/handler.html#on_cancel_capture"},{"doc":"redraw/handler","title":"on_click","content":"pub fn on_click(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_click\nredraw/handler on_click","url":"redraw/handler.html#on_click"},{"doc":"redraw/handler","title":"on_click_capture","content":"pub fn on_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_click_capture\nredraw/handler on_click_capture","url":"redraw/handler.html#on_click_capture"},{"doc":"redraw/handler","title":"on_close","content":"pub fn on_close(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_close\nredraw/handler on_close","url":"redraw/handler.html#on_close"},{"doc":"redraw/handler","title":"on_close_capture","content":"pub fn on_close_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_close_capture\nredraw/handler on_close_capture","url":"redraw/handler.html#on_close_capture"},{"doc":"redraw/handler","title":"on_composition_end","content":"pub fn on_composition_end(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_end\nredraw/handler on_composition_end","url":"redraw/handler.html#on_composition_end"},{"doc":"redraw/handler","title":"on_composition_end_capture","content":"pub fn on_composition_end_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_end_capture\nredraw/handler on_composition_end_capture","url":"redraw/handler.html#on_composition_end_capture"},{"doc":"redraw/handler","title":"on_composition_start","content":"pub fn on_composition_start(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_start\nredraw/handler on_composition_start","url":"redraw/handler.html#on_composition_start"},{"doc":"redraw/handler","title":"on_composition_start_capture","content":"pub fn on_composition_start_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_start_capture\nredraw/handler on_composition_start_capture","url":"redraw/handler.html#on_composition_start_capture"},{"doc":"redraw/handler","title":"on_composition_update","content":"pub fn on_composition_update(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_update\nredraw/handler on_composition_update","url":"redraw/handler.html#on_composition_update"},{"doc":"redraw/handler","title":"on_composition_update_capture","content":"pub fn on_composition_update_capture(\n  handler: fn(CompositionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_composition_update_capture\nredraw/handler on_composition_update_capture","url":"redraw/handler.html#on_composition_update_capture"},{"doc":"redraw/handler","title":"on_context_menu","content":"pub fn on_context_menu(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_context_menu\nredraw/handler on_context_menu","url":"redraw/handler.html#on_context_menu"},{"doc":"redraw/handler","title":"on_context_menu_capture","content":"pub fn on_context_menu_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_context_menu_capture\nredraw/handler on_context_menu_capture","url":"redraw/handler.html#on_context_menu_capture"},{"doc":"redraw/handler","title":"on_copy","content":"pub fn on_copy(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_copy\nredraw/handler on_copy","url":"redraw/handler.html#on_copy"},{"doc":"redraw/handler","title":"on_copy_capture","content":"pub fn on_copy_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_copy_capture\nredraw/handler on_copy_capture","url":"redraw/handler.html#on_copy_capture"},{"doc":"redraw/handler","title":"on_cut","content":"pub fn on_cut(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_cut\nredraw/handler on_cut","url":"redraw/handler.html#on_cut"},{"doc":"redraw/handler","title":"on_cut_capture","content":"pub fn on_cut_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_cut_capture\nredraw/handler on_cut_capture","url":"redraw/handler.html#on_cut_capture"},{"doc":"redraw/handler","title":"on_double_click","content":"pub fn on_double_click(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_double_click\nredraw/handler on_double_click","url":"redraw/handler.html#on_double_click"},{"doc":"redraw/handler","title":"on_double_click_capture","content":"pub fn on_double_click_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_double_click_capture\nredraw/handler on_double_click_capture","url":"redraw/handler.html#on_double_click_capture"},{"doc":"redraw/handler","title":"on_drag","content":"pub fn on_drag(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag\nredraw/handler on_drag","url":"redraw/handler.html#on_drag"},{"doc":"redraw/handler","title":"on_drag_capture","content":"pub fn on_drag_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_capture\nredraw/handler on_drag_capture","url":"redraw/handler.html#on_drag_capture"},{"doc":"redraw/handler","title":"on_drag_end","content":"pub fn on_drag_end(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_end\nredraw/handler on_drag_end","url":"redraw/handler.html#on_drag_end"},{"doc":"redraw/handler","title":"on_drag_end_capture","content":"pub fn on_drag_end_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_end_capture\nredraw/handler on_drag_end_capture","url":"redraw/handler.html#on_drag_end_capture"},{"doc":"redraw/handler","title":"on_drag_enter","content":"pub fn on_drag_enter(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_enter\nredraw/handler on_drag_enter","url":"redraw/handler.html#on_drag_enter"},{"doc":"redraw/handler","title":"on_drag_enter_capture","content":"pub fn on_drag_enter_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_enter_capture\nredraw/handler on_drag_enter_capture","url":"redraw/handler.html#on_drag_enter_capture"},{"doc":"redraw/handler","title":"on_drag_over","content":"pub fn on_drag_over(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_over\nredraw/handler on_drag_over","url":"redraw/handler.html#on_drag_over"},{"doc":"redraw/handler","title":"on_drag_over_capture","content":"pub fn on_drag_over_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_over_capture\nredraw/handler on_drag_over_capture","url":"redraw/handler.html#on_drag_over_capture"},{"doc":"redraw/handler","title":"on_drag_start","content":"pub fn on_drag_start(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_start\nredraw/handler on_drag_start","url":"redraw/handler.html#on_drag_start"},{"doc":"redraw/handler","title":"on_drag_start_capture","content":"pub fn on_drag_start_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drag_start_capture\nredraw/handler on_drag_start_capture","url":"redraw/handler.html#on_drag_start_capture"},{"doc":"redraw/handler","title":"on_drop","content":"pub fn on_drop(handler: fn(DragEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drop\nredraw/handler on_drop","url":"redraw/handler.html#on_drop"},{"doc":"redraw/handler","title":"on_drop_capture","content":"pub fn on_drop_capture(\n  handler: fn(DragEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_drop_capture\nredraw/handler on_drop_capture","url":"redraw/handler.html#on_drop_capture"},{"doc":"redraw/handler","title":"on_duration_change","content":"pub fn on_duration_change(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_duration_change\nredraw/handler on_duration_change","url":"redraw/handler.html#on_duration_change"},{"doc":"redraw/handler","title":"on_duration_change_capture","content":"pub fn on_duration_change_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_duration_change_capture\nredraw/handler on_duration_change_capture","url":"redraw/handler.html#on_duration_change_capture"},{"doc":"redraw/handler","title":"on_emptied","content":"pub fn on_emptied(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_emptied\nredraw/handler on_emptied","url":"redraw/handler.html#on_emptied"},{"doc":"redraw/handler","title":"on_emptied_capture","content":"pub fn on_emptied_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_emptied_capture\nredraw/handler on_emptied_capture","url":"redraw/handler.html#on_emptied_capture"},{"doc":"redraw/handler","title":"on_encrypted","content":"pub fn on_encrypted(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_encrypted\nredraw/handler on_encrypted","url":"redraw/handler.html#on_encrypted"},{"doc":"redraw/handler","title":"on_encrypted_capture","content":"pub fn on_encrypted_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_encrypted_capture\nredraw/handler on_encrypted_capture","url":"redraw/handler.html#on_encrypted_capture"},{"doc":"redraw/handler","title":"on_ended","content":"pub fn on_ended(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_ended\nredraw/handler on_ended","url":"redraw/handler.html#on_ended"},{"doc":"redraw/handler","title":"on_ended_capture","content":"pub fn on_ended_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_ended_capture\nredraw/handler on_ended_capture","url":"redraw/handler.html#on_ended_capture"},{"doc":"redraw/handler","title":"on_error","content":"pub fn on_error(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_error\nredraw/handler on_error","url":"redraw/handler.html#on_error"},{"doc":"redraw/handler","title":"on_error_capture","content":"pub fn on_error_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_error_capture\nredraw/handler on_error_capture","url":"redraw/handler.html#on_error_capture"},{"doc":"redraw/handler","title":"on_focus","content":"pub fn on_focus(handler: fn(FocusEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_focus\nredraw/handler on_focus","url":"redraw/handler.html#on_focus"},{"doc":"redraw/handler","title":"on_focus_capture","content":"pub fn on_focus_capture(\n  handler: fn(FocusEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_focus_capture\nredraw/handler on_focus_capture","url":"redraw/handler.html#on_focus_capture"},{"doc":"redraw/handler","title":"on_got_pointer_capture","content":"pub fn on_got_pointer_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_got_pointer_capture\nredraw/handler on_got_pointer_capture","url":"redraw/handler.html#on_got_pointer_capture"},{"doc":"redraw/handler","title":"on_got_pointer_capture_capture","content":"pub fn on_got_pointer_capture_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_got_pointer_capture_capture\nredraw/handler on_got_pointer_capture_capture","url":"redraw/handler.html#on_got_pointer_capture_capture"},{"doc":"redraw/handler","title":"on_key_down","content":"pub fn on_key_down(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_down\nredraw/handler on_key_down","url":"redraw/handler.html#on_key_down"},{"doc":"redraw/handler","title":"on_key_down_capture","content":"pub fn on_key_down_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_down_capture\nredraw/handler on_key_down_capture","url":"redraw/handler.html#on_key_down_capture"},{"doc":"redraw/handler","title":"on_key_press","content":"pub fn on_key_press(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_press\nredraw/handler on_key_press","url":"redraw/handler.html#on_key_press"},{"doc":"redraw/handler","title":"on_key_press_capture","content":"pub fn on_key_press_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_press_capture\nredraw/handler on_key_press_capture","url":"redraw/handler.html#on_key_press_capture"},{"doc":"redraw/handler","title":"on_key_up","content":"pub fn on_key_up(handler: fn(KeyboardEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_up\nredraw/handler on_key_up","url":"redraw/handler.html#on_key_up"},{"doc":"redraw/handler","title":"on_key_up_capture","content":"pub fn on_key_up_capture(\n  handler: fn(KeyboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_key_up_capture\nredraw/handler on_key_up_capture","url":"redraw/handler.html#on_key_up_capture"},{"doc":"redraw/handler","title":"on_load","content":"pub fn on_load(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_load\nredraw/handler on_load","url":"redraw/handler.html#on_load"},{"doc":"redraw/handler","title":"on_load_capture","content":"pub fn on_load_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_load_capture\nredraw/handler on_load_capture","url":"redraw/handler.html#on_load_capture"},{"doc":"redraw/handler","title":"on_load_start","content":"pub fn on_load_start(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_load_start\nredraw/handler on_load_start","url":"redraw/handler.html#on_load_start"},{"doc":"redraw/handler","title":"on_load_start_capture","content":"pub fn on_load_start_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_load_start_capture\nredraw/handler on_load_start_capture","url":"redraw/handler.html#on_load_start_capture"},{"doc":"redraw/handler","title":"on_loaded_data","content":"pub fn on_loaded_data(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_loaded_data\nredraw/handler on_loaded_data","url":"redraw/handler.html#on_loaded_data"},{"doc":"redraw/handler","title":"on_loaded_data_capture","content":"pub fn on_loaded_data_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_loaded_data_capture\nredraw/handler on_loaded_data_capture","url":"redraw/handler.html#on_loaded_data_capture"},{"doc":"redraw/handler","title":"on_loaded_metadata","content":"pub fn on_loaded_metadata(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_loaded_metadata\nredraw/handler on_loaded_metadata","url":"redraw/handler.html#on_loaded_metadata"},{"doc":"redraw/handler","title":"on_loaded_metadata_capture","content":"pub fn on_loaded_metadata_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_loaded_metadata_capture\nredraw/handler on_loaded_metadata_capture","url":"redraw/handler.html#on_loaded_metadata_capture"},{"doc":"redraw/handler","title":"on_lost_pointer_capture","content":"pub fn on_lost_pointer_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_lost_pointer_capture\nredraw/handler on_lost_pointer_capture","url":"redraw/handler.html#on_lost_pointer_capture"},{"doc":"redraw/handler","title":"on_lost_pointer_capture_capture","content":"pub fn on_lost_pointer_capture_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_lost_pointer_capture_capture\nredraw/handler on_lost_pointer_capture_capture","url":"redraw/handler.html#on_lost_pointer_capture_capture"},{"doc":"redraw/handler","title":"on_mouse_down","content":"pub fn on_mouse_down(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_down\nredraw/handler on_mouse_down","url":"redraw/handler.html#on_mouse_down"},{"doc":"redraw/handler","title":"on_mouse_down_capture","content":"pub fn on_mouse_down_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_down_capture\nredraw/handler on_mouse_down_capture","url":"redraw/handler.html#on_mouse_down_capture"},{"doc":"redraw/handler","title":"on_mouse_enter","content":"pub fn on_mouse_enter(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_enter\nredraw/handler on_mouse_enter","url":"redraw/handler.html#on_mouse_enter"},{"doc":"redraw/handler","title":"on_mouse_leave","content":"pub fn on_mouse_leave(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_leave\nredraw/handler on_mouse_leave","url":"redraw/handler.html#on_mouse_leave"},{"doc":"redraw/handler","title":"on_mouse_move","content":"pub fn on_mouse_move(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_move\nredraw/handler on_mouse_move","url":"redraw/handler.html#on_mouse_move"},{"doc":"redraw/handler","title":"on_mouse_move_capture","content":"pub fn on_mouse_move_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_move_capture\nredraw/handler on_mouse_move_capture","url":"redraw/handler.html#on_mouse_move_capture"},{"doc":"redraw/handler","title":"on_mouse_out","content":"pub fn on_mouse_out(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_out\nredraw/handler on_mouse_out","url":"redraw/handler.html#on_mouse_out"},{"doc":"redraw/handler","title":"on_mouse_out_capture","content":"pub fn on_mouse_out_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_out_capture\nredraw/handler on_mouse_out_capture","url":"redraw/handler.html#on_mouse_out_capture"},{"doc":"redraw/handler","title":"on_mouse_up","content":"pub fn on_mouse_up(handler: fn(MouseEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_up\nredraw/handler on_mouse_up","url":"redraw/handler.html#on_mouse_up"},{"doc":"redraw/handler","title":"on_mouse_up_capture","content":"pub fn on_mouse_up_capture(\n  handler: fn(MouseEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_mouse_up_capture\nredraw/handler on_mouse_up_capture","url":"redraw/handler.html#on_mouse_up_capture"},{"doc":"redraw/handler","title":"on_paste","content":"pub fn on_paste(handler: fn(ClipboardEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_paste\nredraw/handler on_paste","url":"redraw/handler.html#on_paste"},{"doc":"redraw/handler","title":"on_paste_capture","content":"pub fn on_paste_capture(\n  handler: fn(ClipboardEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_paste_capture\nredraw/handler on_paste_capture","url":"redraw/handler.html#on_paste_capture"},{"doc":"redraw/handler","title":"on_pause","content":"pub fn on_pause(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pause\nredraw/handler on_pause","url":"redraw/handler.html#on_pause"},{"doc":"redraw/handler","title":"on_pause_capture","content":"pub fn on_pause_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pause_capture\nredraw/handler on_pause_capture","url":"redraw/handler.html#on_pause_capture"},{"doc":"redraw/handler","title":"on_play","content":"pub fn on_play(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_play\nredraw/handler on_play","url":"redraw/handler.html#on_play"},{"doc":"redraw/handler","title":"on_play_capture","content":"pub fn on_play_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_play_capture\nredraw/handler on_play_capture","url":"redraw/handler.html#on_play_capture"},{"doc":"redraw/handler","title":"on_playing","content":"pub fn on_playing(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_playing\nredraw/handler on_playing","url":"redraw/handler.html#on_playing"},{"doc":"redraw/handler","title":"on_playing_capture","content":"pub fn on_playing_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_playing_capture\nredraw/handler on_playing_capture","url":"redraw/handler.html#on_playing_capture"},{"doc":"redraw/handler","title":"on_pointer_cancel","content":"pub fn on_pointer_cancel(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_cancel\nredraw/handler on_pointer_cancel","url":"redraw/handler.html#on_pointer_cancel"},{"doc":"redraw/handler","title":"on_pointer_cancel_capture","content":"pub fn on_pointer_cancel_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_cancel_capture\nredraw/handler on_pointer_cancel_capture","url":"redraw/handler.html#on_pointer_cancel_capture"},{"doc":"redraw/handler","title":"on_pointer_down","content":"pub fn on_pointer_down(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_down\nredraw/handler on_pointer_down","url":"redraw/handler.html#on_pointer_down"},{"doc":"redraw/handler","title":"on_pointer_down_capture","content":"pub fn on_pointer_down_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_down_capture\nredraw/handler on_pointer_down_capture","url":"redraw/handler.html#on_pointer_down_capture"},{"doc":"redraw/handler","title":"on_pointer_enter","content":"pub fn on_pointer_enter(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_enter\nredraw/handler on_pointer_enter","url":"redraw/handler.html#on_pointer_enter"},{"doc":"redraw/handler","title":"on_pointer_leave","content":"pub fn on_pointer_leave(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_leave\nredraw/handler on_pointer_leave","url":"redraw/handler.html#on_pointer_leave"},{"doc":"redraw/handler","title":"on_pointer_move","content":"pub fn on_pointer_move(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_move\nredraw/handler on_pointer_move","url":"redraw/handler.html#on_pointer_move"},{"doc":"redraw/handler","title":"on_pointer_move_capture","content":"pub fn on_pointer_move_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_move_capture\nredraw/handler on_pointer_move_capture","url":"redraw/handler.html#on_pointer_move_capture"},{"doc":"redraw/handler","title":"on_pointer_out","content":"pub fn on_pointer_out(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_out\nredraw/handler on_pointer_out","url":"redraw/handler.html#on_pointer_out"},{"doc":"redraw/handler","title":"on_pointer_out_capture","content":"pub fn on_pointer_out_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_out_capture\nredraw/handler on_pointer_out_capture","url":"redraw/handler.html#on_pointer_out_capture"},{"doc":"redraw/handler","title":"on_pointer_up","content":"pub fn on_pointer_up(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_up\nredraw/handler on_pointer_up","url":"redraw/handler.html#on_pointer_up"},{"doc":"redraw/handler","title":"on_pointer_up_capture","content":"pub fn on_pointer_up_capture(\n  handler: fn(PointerEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_pointer_up_capture\nredraw/handler on_pointer_up_capture","url":"redraw/handler.html#on_pointer_up_capture"},{"doc":"redraw/handler","title":"on_progress","content":"pub fn on_progress(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_progress\nredraw/handler on_progress","url":"redraw/handler.html#on_progress"},{"doc":"redraw/handler","title":"on_progress_capture","content":"pub fn on_progress_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_progress_capture\nredraw/handler on_progress_capture","url":"redraw/handler.html#on_progress_capture"},{"doc":"redraw/handler","title":"on_rate_change","content":"pub fn on_rate_change(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_rate_change\nredraw/handler on_rate_change","url":"redraw/handler.html#on_rate_change"},{"doc":"redraw/handler","title":"on_rate_change_capture","content":"pub fn on_rate_change_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_rate_change_capture\nredraw/handler on_rate_change_capture","url":"redraw/handler.html#on_rate_change_capture"},{"doc":"redraw/handler","title":"on_reset","content":"pub fn on_reset(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_reset\nredraw/handler on_reset","url":"redraw/handler.html#on_reset"},{"doc":"redraw/handler","title":"on_reset_capture","content":"pub fn on_reset_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_reset_capture\nredraw/handler on_reset_capture","url":"redraw/handler.html#on_reset_capture"},{"doc":"redraw/handler","title":"on_resize","content":"pub fn on_resize(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_resize\nredraw/handler on_resize","url":"redraw/handler.html#on_resize"},{"doc":"redraw/handler","title":"on_resize_capture","content":"pub fn on_resize_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_resize_capture\nredraw/handler on_resize_capture","url":"redraw/handler.html#on_resize_capture"},{"doc":"redraw/handler","title":"on_scroll","content":"pub fn on_scroll(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_scroll\nredraw/handler on_scroll","url":"redraw/handler.html#on_scroll"},{"doc":"redraw/handler","title":"on_scroll_capture","content":"pub fn on_scroll_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_scroll_capture\nredraw/handler on_scroll_capture","url":"redraw/handler.html#on_scroll_capture"},{"doc":"redraw/handler","title":"on_seeked","content":"pub fn on_seeked(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_seeked\nredraw/handler on_seeked","url":"redraw/handler.html#on_seeked"},{"doc":"redraw/handler","title":"on_seeked_capture","content":"pub fn on_seeked_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_seeked_capture\nredraw/handler on_seeked_capture","url":"redraw/handler.html#on_seeked_capture"},{"doc":"redraw/handler","title":"on_seeking","content":"pub fn on_seeking(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_seeking\nredraw/handler on_seeking","url":"redraw/handler.html#on_seeking"},{"doc":"redraw/handler","title":"on_seeking_capture","content":"pub fn on_seeking_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_seeking_capture\nredraw/handler on_seeking_capture","url":"redraw/handler.html#on_seeking_capture"},{"doc":"redraw/handler","title":"on_select","content":"pub fn on_select(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_select\nredraw/handler on_select","url":"redraw/handler.html#on_select"},{"doc":"redraw/handler","title":"on_select_capture","content":"pub fn on_select_capture(handler: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_select_capture\nredraw/handler on_select_capture","url":"redraw/handler.html#on_select_capture"},{"doc":"redraw/handler","title":"on_stalled","content":"pub fn on_stalled(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_stalled\nredraw/handler on_stalled","url":"redraw/handler.html#on_stalled"},{"doc":"redraw/handler","title":"on_stalled_capture","content":"pub fn on_stalled_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_stalled_capture\nredraw/handler on_stalled_capture","url":"redraw/handler.html#on_stalled_capture"},{"doc":"redraw/handler","title":"on_submit","content":"pub fn on_submit(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_submit\nredraw/handler on_submit","url":"redraw/handler.html#on_submit"},{"doc":"redraw/handler","title":"on_submit_capture","content":"pub fn on_submit_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_submit_capture\nredraw/handler on_submit_capture","url":"redraw/handler.html#on_submit_capture"},{"doc":"redraw/handler","title":"on_suspend","content":"pub fn on_suspend(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_suspend\nredraw/handler on_suspend","url":"redraw/handler.html#on_suspend"},{"doc":"redraw/handler","title":"on_suspend_capture","content":"pub fn on_suspend_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_suspend_capture\nredraw/handler on_suspend_capture","url":"redraw/handler.html#on_suspend_capture"},{"doc":"redraw/handler","title":"on_time_update","content":"pub fn on_time_update(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_time_update\nredraw/handler on_time_update","url":"redraw/handler.html#on_time_update"},{"doc":"redraw/handler","title":"on_time_update_capture","content":"pub fn on_time_update_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_time_update_capture\nredraw/handler on_time_update_capture","url":"redraw/handler.html#on_time_update_capture"},{"doc":"redraw/handler","title":"on_toggle","content":"pub fn on_toggle(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_toggle\nredraw/handler on_toggle","url":"redraw/handler.html#on_toggle"},{"doc":"redraw/handler","title":"on_toggle_capture","content":"pub fn on_toggle_capture(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_toggle_capture\nredraw/handler on_toggle_capture","url":"redraw/handler.html#on_toggle_capture"},{"doc":"redraw/handler","title":"on_touch_cancel","content":"pub fn on_touch_cancel(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_cancel\nredraw/handler on_touch_cancel","url":"redraw/handler.html#on_touch_cancel"},{"doc":"redraw/handler","title":"on_touch_cancel_capture","content":"pub fn on_touch_cancel_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_cancel_capture\nredraw/handler on_touch_cancel_capture","url":"redraw/handler.html#on_touch_cancel_capture"},{"doc":"redraw/handler","title":"on_touch_end","content":"pub fn on_touch_end(handler: fn(TouchEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_end\nredraw/handler on_touch_end","url":"redraw/handler.html#on_touch_end"},{"doc":"redraw/handler","title":"on_touch_end_capture","content":"pub fn on_touch_end_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_end_capture\nredraw/handler on_touch_end_capture","url":"redraw/handler.html#on_touch_end_capture"},{"doc":"redraw/handler","title":"on_touch_move","content":"pub fn on_touch_move(handler: fn(TouchEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_move\nredraw/handler on_touch_move","url":"redraw/handler.html#on_touch_move"},{"doc":"redraw/handler","title":"on_touch_move_capture","content":"pub fn on_touch_move_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_move_capture\nredraw/handler on_touch_move_capture","url":"redraw/handler.html#on_touch_move_capture"},{"doc":"redraw/handler","title":"on_touch_start","content":"pub fn on_touch_start(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_start\nredraw/handler on_touch_start","url":"redraw/handler.html#on_touch_start"},{"doc":"redraw/handler","title":"on_touch_start_capture","content":"pub fn on_touch_start_capture(\n  handler: fn(TouchEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_touch_start_capture\nredraw/handler on_touch_start_capture","url":"redraw/handler.html#on_touch_start_capture"},{"doc":"redraw/handler","title":"on_transition_end","content":"pub fn on_transition_end(\n  handler: fn(TransitionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_transition_end\nredraw/handler on_transition_end","url":"redraw/handler.html#on_transition_end"},{"doc":"redraw/handler","title":"on_transition_end_capture","content":"pub fn on_transition_end_capture(\n  handler: fn(TransitionEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_transition_end_capture\nredraw/handler on_transition_end_capture","url":"redraw/handler.html#on_transition_end_capture"},{"doc":"redraw/handler","title":"on_volume_change","content":"pub fn on_volume_change(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_volume_change\nredraw/handler on_volume_change","url":"redraw/handler.html#on_volume_change"},{"doc":"redraw/handler","title":"on_volume_change_capture","content":"pub fn on_volume_change_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_volume_change_capture\nredraw/handler on_volume_change_capture","url":"redraw/handler.html#on_volume_change_capture"},{"doc":"redraw/handler","title":"on_waiting","content":"pub fn on_waiting(callback: fn(Event) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_waiting\nredraw/handler on_waiting","url":"redraw/handler.html#on_waiting"},{"doc":"redraw/handler","title":"on_waiting_capture","content":"pub fn on_waiting_capture(\n  callback: fn(Event) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_waiting_capture\nredraw/handler on_waiting_capture","url":"redraw/handler.html#on_waiting_capture"},{"doc":"redraw/handler","title":"on_wheel","content":"pub fn on_wheel(handler: fn(WheelEvent) -&gt; Nil) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_wheel\nredraw/handler on_wheel","url":"redraw/handler.html#on_wheel"},{"doc":"redraw/handler","title":"on_wheel_capture","content":"pub fn on_wheel_capture(\n  handler: fn(WheelEvent) -&gt; Nil,\n) -&gt; Attribute\n\nSynonyms:\nredraw/handler.on_wheel_capture\nredraw/handler on_wheel_capture","url":"redraw/handler.html#on_wheel_capture"},{"doc":"redraw/handler","title":"redraw/handler","content":"","url":"redraw/handler.html"},{"doc":"redraw/html","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.a\nredraw/html a","url":"redraw/html.html#a"},{"doc":"redraw/html","title":"abbr","content":"pub fn abbr(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.abbr\nredraw/html abbr","url":"redraw/html.html#abbr"},{"doc":"redraw/html","title":"address","content":"pub fn address(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.address\nredraw/html address","url":"redraw/html.html#address"},{"doc":"redraw/html","title":"area","content":"pub fn area(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.area\nredraw/html area","url":"redraw/html.html#area"},{"doc":"redraw/html","title":"article","content":"pub fn article(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.article\nredraw/html article","url":"redraw/html.html#article"},{"doc":"redraw/html","title":"aside","content":"pub fn aside(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.aside\nredraw/html aside","url":"redraw/html.html#aside"},{"doc":"redraw/html","title":"audio","content":"pub fn audio(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.audio\nredraw/html audio","url":"redraw/html.html#audio"},{"doc":"redraw/html","title":"b","content":"pub fn b(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.b\nredraw/html b","url":"redraw/html.html#b"},{"doc":"redraw/html","title":"base","content":"pub fn base(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.base\nredraw/html base","url":"redraw/html.html#base"},{"doc":"redraw/html","title":"bdi","content":"pub fn bdi(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.bdi\nredraw/html bdi","url":"redraw/html.html#bdi"},{"doc":"redraw/html","title":"bdo","content":"pub fn bdo(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.bdo\nredraw/html bdo","url":"redraw/html.html#bdo"},{"doc":"redraw/html","title":"blockquote","content":"pub fn blockquote(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.blockquote\nredraw/html blockquote","url":"redraw/html.html#blockquote"},{"doc":"redraw/html","title":"body","content":"pub fn body(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.body\nredraw/html body","url":"redraw/html.html#body"},{"doc":"redraw/html","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.br\nredraw/html br","url":"redraw/html.html#br"},{"doc":"redraw/html","title":"button","content":"pub fn button(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.button\nredraw/html button","url":"redraw/html.html#button"},{"doc":"redraw/html","title":"canvas","content":"pub fn canvas(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.canvas\nredraw/html canvas","url":"redraw/html.html#canvas"},{"doc":"redraw/html","title":"caption","content":"pub fn caption(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.caption\nredraw/html caption","url":"redraw/html.html#caption"},{"doc":"redraw/html","title":"cite","content":"pub fn cite(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.cite\nredraw/html cite","url":"redraw/html.html#cite"},{"doc":"redraw/html","title":"code","content":"pub fn code(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.code\nredraw/html code","url":"redraw/html.html#code"},{"doc":"redraw/html","title":"col","content":"pub fn col(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.col\nredraw/html col","url":"redraw/html.html#col"},{"doc":"redraw/html","title":"colgroup","content":"pub fn colgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.colgroup\nredraw/html colgroup","url":"redraw/html.html#colgroup"},{"doc":"redraw/html","title":"data","content":"pub fn data(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.data\nredraw/html data","url":"redraw/html.html#data"},{"doc":"redraw/html","title":"datalist","content":"pub fn datalist(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.datalist\nredraw/html datalist","url":"redraw/html.html#datalist"},{"doc":"redraw/html","title":"dd","content":"pub fn dd(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.dd\nredraw/html dd","url":"redraw/html.html#dd"},{"doc":"redraw/html","title":"del","content":"pub fn del(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.del\nredraw/html del","url":"redraw/html.html#del"},{"doc":"redraw/html","title":"details","content":"pub fn details(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.details\nredraw/html details","url":"redraw/html.html#details"},{"doc":"redraw/html","title":"dfn","content":"pub fn dfn(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.dfn\nredraw/html dfn","url":"redraw/html.html#dfn"},{"doc":"redraw/html","title":"dialog","content":"pub fn dialog(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.dialog\nredraw/html dialog","url":"redraw/html.html#dialog"},{"doc":"redraw/html","title":"div","content":"pub fn div(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.div\nredraw/html div","url":"redraw/html.html#div"},{"doc":"redraw/html","title":"dl","content":"pub fn dl(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.dl\nredraw/html dl","url":"redraw/html.html#dl"},{"doc":"redraw/html","title":"dt","content":"pub fn dt(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.dt\nredraw/html dt","url":"redraw/html.html#dt"},{"doc":"redraw/html","title":"em","content":"pub fn em(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.em\nredraw/html em","url":"redraw/html.html#em"},{"doc":"redraw/html","title":"embed","content":"pub fn embed(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.embed\nredraw/html embed","url":"redraw/html.html#embed"},{"doc":"redraw/html","title":"fieldset","content":"pub fn fieldset(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.fieldset\nredraw/html fieldset","url":"redraw/html.html#fieldset"},{"doc":"redraw/html","title":"figcaption","content":"pub fn figcaption(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.figcaption\nredraw/html figcaption","url":"redraw/html.html#figcaption"},{"doc":"redraw/html","title":"figure","content":"pub fn figure(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.figure\nredraw/html figure","url":"redraw/html.html#figure"},{"doc":"redraw/html","title":"footer","content":"pub fn footer(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.footer\nredraw/html footer","url":"redraw/html.html#footer"},{"doc":"redraw/html","title":"form","content":"pub fn form(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.form\nredraw/html form","url":"redraw/html.html#form"},{"doc":"redraw/html","title":"h1","content":"pub fn h1(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.h1\nredraw/html h1","url":"redraw/html.html#h1"},{"doc":"redraw/html","title":"h2","content":"pub fn h2(attrs: List(Attribute), children: a) -&gt; Component\n\nSynonyms:\nredraw/html.h2\nredraw/html h2","url":"redraw/html.html#h2"},{"doc":"redraw/html","title":"h3","content":"pub fn h3(attrs: List(Attribute), children: a) -&gt; Component\n\nSynonyms:\nredraw/html.h3\nredraw/html h3","url":"redraw/html.html#h3"},{"doc":"redraw/html","title":"h4","content":"pub fn h4(attrs: List(Attribute), children: a) -&gt; Component\n\nSynonyms:\nredraw/html.h4\nredraw/html h4","url":"redraw/html.html#h4"},{"doc":"redraw/html","title":"h5","content":"pub fn h5(attrs: List(Attribute), children: a) -&gt; Component\n\nSynonyms:\nredraw/html.h5\nredraw/html h5","url":"redraw/html.html#h5"},{"doc":"redraw/html","title":"h6","content":"pub fn h6(attrs: List(Attribute), children: a) -&gt; Component\n\nSynonyms:\nredraw/html.h6\nredraw/html h6","url":"redraw/html.html#h6"},{"doc":"redraw/html","title":"head","content":"pub fn head(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.head\nredraw/html head","url":"redraw/html.html#head"},{"doc":"redraw/html","title":"header","content":"pub fn header(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.header\nredraw/html header","url":"redraw/html.html#header"},{"doc":"redraw/html","title":"hgroup","content":"pub fn hgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.hgroup\nredraw/html hgroup","url":"redraw/html.html#hgroup"},{"doc":"redraw/html","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.hr\nredraw/html hr","url":"redraw/html.html#hr"},{"doc":"redraw/html","title":"html","content":"pub fn html(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.html\nredraw/html html","url":"redraw/html.html#html"},{"doc":"redraw/html","title":"i","content":"pub fn i(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.i\nredraw/html i","url":"redraw/html.html#i"},{"doc":"redraw/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.iframe\nredraw/html iframe","url":"redraw/html.html#iframe"},{"doc":"redraw/html","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.img\nredraw/html img","url":"redraw/html.html#img"},{"doc":"redraw/html","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.input\nredraw/html input","url":"redraw/html.html#input"},{"doc":"redraw/html","title":"ins","content":"pub fn ins(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.ins\nredraw/html ins","url":"redraw/html.html#ins"},{"doc":"redraw/html","title":"kbd","content":"pub fn kbd(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.kbd\nredraw/html kbd","url":"redraw/html.html#kbd"},{"doc":"redraw/html","title":"label","content":"pub fn label(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.label\nredraw/html label","url":"redraw/html.html#label"},{"doc":"redraw/html","title":"legend","content":"pub fn legend(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.legend\nredraw/html legend","url":"redraw/html.html#legend"},{"doc":"redraw/html","title":"li","content":"pub fn li(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.li\nredraw/html li","url":"redraw/html.html#li"},{"doc":"redraw/html","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.link\nredraw/html link","url":"redraw/html.html#link"},{"doc":"redraw/html","title":"main","content":"pub fn main(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.main\nredraw/html main","url":"redraw/html.html#main"},{"doc":"redraw/html","title":"map","content":"pub fn map(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.map\nredraw/html map","url":"redraw/html.html#map"},{"doc":"redraw/html","title":"mark","content":"pub fn mark(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.mark\nredraw/html mark","url":"redraw/html.html#mark"},{"doc":"redraw/html","title":"menu","content":"pub fn menu(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.menu\nredraw/html menu","url":"redraw/html.html#menu"},{"doc":"redraw/html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.meta\nredraw/html meta","url":"redraw/html.html#meta"},{"doc":"redraw/html","title":"meter","content":"pub fn meter(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.meter\nredraw/html meter","url":"redraw/html.html#meter"},{"doc":"redraw/html","title":"nav","content":"pub fn nav(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.nav\nredraw/html nav","url":"redraw/html.html#nav"},{"doc":"redraw/html","title":"noscript","content":"pub fn noscript(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.noscript\nredraw/html noscript","url":"redraw/html.html#noscript"},{"doc":"redraw/html","title":"object","content":"pub fn object(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.object\nredraw/html object","url":"redraw/html.html#object"},{"doc":"redraw/html","title":"ol","content":"pub fn ol(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.ol\nredraw/html ol","url":"redraw/html.html#ol"},{"doc":"redraw/html","title":"optgroup","content":"pub fn optgroup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.optgroup\nredraw/html optgroup","url":"redraw/html.html#optgroup"},{"doc":"redraw/html","title":"option","content":"pub fn option(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.option\nredraw/html option","url":"redraw/html.html#option"},{"doc":"redraw/html","title":"output","content":"pub fn output(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.output\nredraw/html output","url":"redraw/html.html#output"},{"doc":"redraw/html","title":"p","content":"pub fn p(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.p\nredraw/html p","url":"redraw/html.html#p"},{"doc":"redraw/html","title":"picture","content":"pub fn picture(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.picture\nredraw/html picture","url":"redraw/html.html#picture"},{"doc":"redraw/html","title":"pre","content":"pub fn pre(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.pre\nredraw/html pre","url":"redraw/html.html#pre"},{"doc":"redraw/html","title":"progress","content":"pub fn progress(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.progress\nredraw/html progress","url":"redraw/html.html#progress"},{"doc":"redraw/html","title":"q","content":"pub fn q(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.q\nredraw/html q","url":"redraw/html.html#q"},{"doc":"redraw/html","title":"rp","content":"pub fn rp(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.rp\nredraw/html rp","url":"redraw/html.html#rp"},{"doc":"redraw/html","title":"rt","content":"pub fn rt(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.rt\nredraw/html rt","url":"redraw/html.html#rt"},{"doc":"redraw/html","title":"ruby","content":"pub fn ruby(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.ruby\nredraw/html ruby","url":"redraw/html.html#ruby"},{"doc":"redraw/html","title":"s","content":"pub fn s(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.s\nredraw/html s","url":"redraw/html.html#s"},{"doc":"redraw/html","title":"samp","content":"pub fn samp(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.samp\nredraw/html samp","url":"redraw/html.html#samp"},{"doc":"redraw/html","title":"script","content":"pub fn script(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.script\nredraw/html script","url":"redraw/html.html#script"},{"doc":"redraw/html","title":"section","content":"pub fn section(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.section\nredraw/html section","url":"redraw/html.html#section"},{"doc":"redraw/html","title":"select","content":"pub fn select(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.select\nredraw/html select","url":"redraw/html.html#select"},{"doc":"redraw/html","title":"slot","content":"pub fn slot(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.slot\nredraw/html slot","url":"redraw/html.html#slot"},{"doc":"redraw/html","title":"small","content":"pub fn small(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.small\nredraw/html small","url":"redraw/html.html#small"},{"doc":"redraw/html","title":"source","content":"pub fn source(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.source\nredraw/html source","url":"redraw/html.html#source"},{"doc":"redraw/html","title":"span","content":"pub fn span(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.span\nredraw/html span","url":"redraw/html.html#span"},{"doc":"redraw/html","title":"strong","content":"pub fn strong(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.strong\nredraw/html strong","url":"redraw/html.html#strong"},{"doc":"redraw/html","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n\nSynonyms:\nredraw/html.style\nredraw/html style","url":"redraw/html.html#style"},{"doc":"redraw/html","title":"sub","content":"pub fn sub(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.sub\nredraw/html sub","url":"redraw/html.html#sub"},{"doc":"redraw/html","title":"summary","content":"pub fn summary(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.summary\nredraw/html summary","url":"redraw/html.html#summary"},{"doc":"redraw/html","title":"sup","content":"pub fn sup(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.sup\nredraw/html sup","url":"redraw/html.html#sup"},{"doc":"redraw/html","title":"table","content":"pub fn table(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.table\nredraw/html table","url":"redraw/html.html#table"},{"doc":"redraw/html","title":"tbody","content":"pub fn tbody(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.tbody\nredraw/html tbody","url":"redraw/html.html#tbody"},{"doc":"redraw/html","title":"td","content":"pub fn td(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.td\nredraw/html td","url":"redraw/html.html#td"},{"doc":"redraw/html","title":"template","content":"pub fn template(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.template\nredraw/html template","url":"redraw/html.html#template"},{"doc":"redraw/html","title":"text","content":"pub fn text(content: String) -&gt; Component\n\nSynonyms:\nredraw/html.text\nredraw/html text","url":"redraw/html.html#text"},{"doc":"redraw/html","title":"textarea","content":"pub fn textarea(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.textarea\nredraw/html textarea","url":"redraw/html.html#textarea"},{"doc":"redraw/html","title":"tfoot","content":"pub fn tfoot(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.tfoot\nredraw/html tfoot","url":"redraw/html.html#tfoot"},{"doc":"redraw/html","title":"th","content":"pub fn th(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.th\nredraw/html th","url":"redraw/html.html#th"},{"doc":"redraw/html","title":"thead","content":"pub fn thead(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.thead\nredraw/html thead","url":"redraw/html.html#thead"},{"doc":"redraw/html","title":"time","content":"pub fn time(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.time\nredraw/html time","url":"redraw/html.html#time"},{"doc":"redraw/html","title":"title","content":"pub fn title(\n  attrs: List(Attribute),\n  content: String,\n) -&gt; Component\n\nSynonyms:\nredraw/html.title\nredraw/html title","url":"redraw/html.html#title"},{"doc":"redraw/html","title":"tr","content":"pub fn tr(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.tr\nredraw/html tr","url":"redraw/html.html#tr"},{"doc":"redraw/html","title":"track","content":"pub fn track(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.track\nredraw/html track","url":"redraw/html.html#track"},{"doc":"redraw/html","title":"u","content":"pub fn u(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.u\nredraw/html u","url":"redraw/html.html#u"},{"doc":"redraw/html","title":"ul","content":"pub fn ul(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.ul\nredraw/html ul","url":"redraw/html.html#ul"},{"doc":"redraw/html","title":"var","content":"pub fn var(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.var\nredraw/html var","url":"redraw/html.html#var"},{"doc":"redraw/html","title":"video","content":"pub fn video(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/html.video\nredraw/html video","url":"redraw/html.html#video"},{"doc":"redraw/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute)) -&gt; Component\n\nSynonyms:\nredraw/html.wbr\nredraw/html wbr","url":"redraw/html.html#wbr"},{"doc":"redraw/html","title":"redraw/html","content":"","url":"redraw/html.html"},{"doc":"redraw/svg","title":"a","content":"pub fn a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.a\nredraw/svg a","url":"redraw/svg.html#a"},{"doc":"redraw/svg","title":"animate","content":"pub fn animate(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.animate\nredraw/svg animate","url":"redraw/svg.html#animate"},{"doc":"redraw/svg","title":"animate_motion","content":"pub fn animate_motion(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.animate_motion\nredraw/svg animate_motion","url":"redraw/svg.html#animate_motion"},{"doc":"redraw/svg","title":"animate_transform","content":"pub fn animate_transform(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.animate_transform\nredraw/svg animate_transform","url":"redraw/svg.html#animate_transform"},{"doc":"redraw/svg","title":"circle","content":"pub fn circle(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.circle\nredraw/svg circle","url":"redraw/svg.html#circle"},{"doc":"redraw/svg","title":"clip_path","content":"pub fn clip_path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.clip_path\nredraw/svg clip_path","url":"redraw/svg.html#clip_path"},{"doc":"redraw/svg","title":"defs","content":"pub fn defs(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.defs\nredraw/svg defs","url":"redraw/svg.html#defs"},{"doc":"redraw/svg","title":"desc","content":"pub fn desc(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.desc\nredraw/svg desc","url":"redraw/svg.html#desc"},{"doc":"redraw/svg","title":"discard","content":"pub fn discard(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.discard\nredraw/svg discard","url":"redraw/svg.html#discard"},{"doc":"redraw/svg","title":"ellipse","content":"pub fn ellipse(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.ellipse\nredraw/svg ellipse","url":"redraw/svg.html#ellipse"},{"doc":"redraw/svg","title":"fe_blend","content":"pub fn fe_blend(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_blend\nredraw/svg fe_blend","url":"redraw/svg.html#fe_blend"},{"doc":"redraw/svg","title":"fe_color_matrix","content":"pub fn fe_color_matrix(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_color_matrix\nredraw/svg fe_color_matrix","url":"redraw/svg.html#fe_color_matrix"},{"doc":"redraw/svg","title":"fe_component_transfer","content":"pub fn fe_component_transfer(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_component_transfer\nredraw/svg fe_component_transfer","url":"redraw/svg.html#fe_component_transfer"},{"doc":"redraw/svg","title":"fe_composite","content":"pub fn fe_composite(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_composite\nredraw/svg fe_composite","url":"redraw/svg.html#fe_composite"},{"doc":"redraw/svg","title":"fe_convolve_matrix","content":"pub fn fe_convolve_matrix(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_convolve_matrix\nredraw/svg fe_convolve_matrix","url":"redraw/svg.html#fe_convolve_matrix"},{"doc":"redraw/svg","title":"fe_diffuse_lighting","content":"pub fn fe_diffuse_lighting(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_diffuse_lighting\nredraw/svg fe_diffuse_lighting","url":"redraw/svg.html#fe_diffuse_lighting"},{"doc":"redraw/svg","title":"fe_displacement_map","content":"pub fn fe_displacement_map(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_displacement_map\nredraw/svg fe_displacement_map","url":"redraw/svg.html#fe_displacement_map"},{"doc":"redraw/svg","title":"fe_distant_light","content":"pub fn fe_distant_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_distant_light\nredraw/svg fe_distant_light","url":"redraw/svg.html#fe_distant_light"},{"doc":"redraw/svg","title":"fe_drop_shadow","content":"pub fn fe_drop_shadow(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_drop_shadow\nredraw/svg fe_drop_shadow","url":"redraw/svg.html#fe_drop_shadow"},{"doc":"redraw/svg","title":"fe_flood","content":"pub fn fe_flood(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_flood\nredraw/svg fe_flood","url":"redraw/svg.html#fe_flood"},{"doc":"redraw/svg","title":"fe_func_a","content":"pub fn fe_func_a(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_func_a\nredraw/svg fe_func_a","url":"redraw/svg.html#fe_func_a"},{"doc":"redraw/svg","title":"fe_func_b","content":"pub fn fe_func_b(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_func_b\nredraw/svg fe_func_b","url":"redraw/svg.html#fe_func_b"},{"doc":"redraw/svg","title":"fe_func_g","content":"pub fn fe_func_g(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_func_g\nredraw/svg fe_func_g","url":"redraw/svg.html#fe_func_g"},{"doc":"redraw/svg","title":"fe_func_r","content":"pub fn fe_func_r(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_func_r\nredraw/svg fe_func_r","url":"redraw/svg.html#fe_func_r"},{"doc":"redraw/svg","title":"fe_gaussian_blur","content":"pub fn fe_gaussian_blur(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_gaussian_blur\nredraw/svg fe_gaussian_blur","url":"redraw/svg.html#fe_gaussian_blur"},{"doc":"redraw/svg","title":"fe_image","content":"pub fn fe_image(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_image\nredraw/svg fe_image","url":"redraw/svg.html#fe_image"},{"doc":"redraw/svg","title":"fe_merge","content":"pub fn fe_merge(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_merge\nredraw/svg fe_merge","url":"redraw/svg.html#fe_merge"},{"doc":"redraw/svg","title":"fe_merge_node","content":"pub fn fe_merge_node(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_merge_node\nredraw/svg fe_merge_node","url":"redraw/svg.html#fe_merge_node"},{"doc":"redraw/svg","title":"fe_morphology","content":"pub fn fe_morphology(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_morphology\nredraw/svg fe_morphology","url":"redraw/svg.html#fe_morphology"},{"doc":"redraw/svg","title":"fe_offset","content":"pub fn fe_offset(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_offset\nredraw/svg fe_offset","url":"redraw/svg.html#fe_offset"},{"doc":"redraw/svg","title":"fe_point_light","content":"pub fn fe_point_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_point_light\nredraw/svg fe_point_light","url":"redraw/svg.html#fe_point_light"},{"doc":"redraw/svg","title":"fe_specular_lighting","content":"pub fn fe_specular_lighting(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_specular_lighting\nredraw/svg fe_specular_lighting","url":"redraw/svg.html#fe_specular_lighting"},{"doc":"redraw/svg","title":"fe_spot_light","content":"pub fn fe_spot_light(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_spot_light\nredraw/svg fe_spot_light","url":"redraw/svg.html#fe_spot_light"},{"doc":"redraw/svg","title":"fe_tile","content":"pub fn fe_tile(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_tile\nredraw/svg fe_tile","url":"redraw/svg.html#fe_tile"},{"doc":"redraw/svg","title":"fe_turbulence","content":"pub fn fe_turbulence(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.fe_turbulence\nredraw/svg fe_turbulence","url":"redraw/svg.html#fe_turbulence"},{"doc":"redraw/svg","title":"filter","content":"pub fn filter(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.filter\nredraw/svg filter","url":"redraw/svg.html#filter"},{"doc":"redraw/svg","title":"foreign_object","content":"pub fn foreign_object(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.foreign_object\nredraw/svg foreign_object","url":"redraw/svg.html#foreign_object"},{"doc":"redraw/svg","title":"g","content":"pub fn g(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.g\nredraw/svg g","url":"redraw/svg.html#g"},{"doc":"redraw/svg","title":"hatch","content":"pub fn hatch(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.hatch\nredraw/svg hatch","url":"redraw/svg.html#hatch"},{"doc":"redraw/svg","title":"hatchpath","content":"pub fn hatchpath(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.hatchpath\nredraw/svg hatchpath","url":"redraw/svg.html#hatchpath"},{"doc":"redraw/svg","title":"image","content":"pub fn image(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.image\nredraw/svg image","url":"redraw/svg.html#image"},{"doc":"redraw/svg","title":"line","content":"pub fn line(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.line\nredraw/svg line","url":"redraw/svg.html#line"},{"doc":"redraw/svg","title":"linear_gradient","content":"pub fn linear_gradient(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.linear_gradient\nredraw/svg linear_gradient","url":"redraw/svg.html#linear_gradient"},{"doc":"redraw/svg","title":"marker","content":"pub fn marker(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.marker\nredraw/svg marker","url":"redraw/svg.html#marker"},{"doc":"redraw/svg","title":"mask","content":"pub fn mask(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.mask\nredraw/svg mask","url":"redraw/svg.html#mask"},{"doc":"redraw/svg","title":"metadata","content":"pub fn metadata(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.metadata\nredraw/svg metadata","url":"redraw/svg.html#metadata"},{"doc":"redraw/svg","title":"mpath","content":"pub fn mpath(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.mpath\nredraw/svg mpath","url":"redraw/svg.html#mpath"},{"doc":"redraw/svg","title":"path","content":"pub fn path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.path\nredraw/svg path","url":"redraw/svg.html#path"},{"doc":"redraw/svg","title":"pattern","content":"pub fn pattern(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.pattern\nredraw/svg pattern","url":"redraw/svg.html#pattern"},{"doc":"redraw/svg","title":"polygon","content":"pub fn polygon(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.polygon\nredraw/svg polygon","url":"redraw/svg.html#polygon"},{"doc":"redraw/svg","title":"polyline","content":"pub fn polyline(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.polyline\nredraw/svg polyline","url":"redraw/svg.html#polyline"},{"doc":"redraw/svg","title":"radial_gradient","content":"pub fn radial_gradient(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.radial_gradient\nredraw/svg radial_gradient","url":"redraw/svg.html#radial_gradient"},{"doc":"redraw/svg","title":"rect","content":"pub fn rect(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.rect\nredraw/svg rect","url":"redraw/svg.html#rect"},{"doc":"redraw/svg","title":"script","content":"pub fn script(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.script\nredraw/svg script","url":"redraw/svg.html#script"},{"doc":"redraw/svg","title":"set","content":"pub fn set(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.set\nredraw/svg set","url":"redraw/svg.html#set"},{"doc":"redraw/svg","title":"stop","content":"pub fn stop(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.stop\nredraw/svg stop","url":"redraw/svg.html#stop"},{"doc":"redraw/svg","title":"style","content":"pub fn style(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.style\nredraw/svg style","url":"redraw/svg.html#style"},{"doc":"redraw/svg","title":"svg","content":"pub fn svg(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.svg\nredraw/svg svg","url":"redraw/svg.html#svg"},{"doc":"redraw/svg","title":"switch","content":"pub fn switch(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.switch\nredraw/svg switch","url":"redraw/svg.html#switch"},{"doc":"redraw/svg","title":"symbol","content":"pub fn symbol(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.symbol\nredraw/svg symbol","url":"redraw/svg.html#symbol"},{"doc":"redraw/svg","title":"text","content":"pub fn text(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.text\nredraw/svg text","url":"redraw/svg.html#text"},{"doc":"redraw/svg","title":"text_path","content":"pub fn text_path(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.text_path\nredraw/svg text_path","url":"redraw/svg.html#text_path"},{"doc":"redraw/svg","title":"title","content":"pub fn title(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.title\nredraw/svg title","url":"redraw/svg.html#title"},{"doc":"redraw/svg","title":"tspan","content":"pub fn tspan(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.tspan\nredraw/svg tspan","url":"redraw/svg.html#tspan"},{"doc":"redraw/svg","title":"use_","content":"pub fn use_(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.use_\nredraw/svg use_","url":"redraw/svg.html#use_"},{"doc":"redraw/svg","title":"view","content":"pub fn view(\n  attrs: List(Attribute),\n  children: List(Component),\n) -&gt; Component\n\nSynonyms:\nredraw/svg.view\nredraw/svg view","url":"redraw/svg.html#view"},{"doc":"redraw/svg","title":"redraw/svg","content":"","url":"redraw/svg.html"}]);